"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def acknowledge_job(jobId=None, nonce=None):
    """
    :param jobId: [REQUIRED]
            The unique system-generated ID of the job for which you want to confirm receipt.
            
    :type jobId: string
    :param nonce: [REQUIRED]
            A system-generated random number that AWS CodePipeline uses to ensure that the job is being worked on by only one job worker. This number must be returned in the response.
            
    :type nonce: string
    """
    pass

def acknowledge_third_party_job(jobId=None, nonce=None, clientToken=None):
    """
    :param jobId: [REQUIRED]
            The unique system-generated ID of the job.
            
    :type jobId: string
    :param nonce: [REQUIRED]
            A system-generated random number that AWS CodePipeline uses to ensure that the job is being worked on by only one job worker. This number must be returned in the response.
            
    :type nonce: string
    :param clientToken: [REQUIRED]
            The clientToken portion of the clientId and clientToken pair used to verify that the calling entity is allowed access to the job and its details.
            
    :type clientToken: string
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_custom_action_type(category=None, provider=None, version=None, settings=None, configurationProperties=None, inputArtifactDetails=None, outputArtifactDetails=None):
    """
    :param category: [REQUIRED]
            The category of the custom action, such as a build action or a test action.
            Note
            Although Source and Approval are listed as valid values, they are not currently functional. These values are reserved for future use.
            
    :type category: string
    :param provider: [REQUIRED]
            The provider of the service used in the custom action, such as AWS CodeDeploy.
            
    :type provider: string
    :param version: [REQUIRED]
            The version identifier of the custom action.
            
    :type version: string
    :param settings: Returns information about the settings for an action type.
            thirdPartyConfigurationUrl (string) --The URL of a sign-up page where users can sign up for an external service and perform initial configuration of the action provided by that service.
            entityUrlTemplate (string) --The URL returned to the AWS CodePipeline console that provides a deep link to the resources of the external system, such as the configuration page for an AWS CodeDeploy deployment group. This link is provided as part of the action display within the pipeline.
            executionUrlTemplate (string) --The URL returned to the AWS CodePipeline console that contains a link to the top-level landing page for the external system, such as console page for AWS CodeDeploy. This link is shown on the pipeline view page in the AWS CodePipeline console and provides a link to the execution entity of the external action.
            revisionUrlTemplate (string) --The URL returned to the AWS CodePipeline console that contains a link to the page where customers can update or change the configuration of the external action.
            
    :type settings: dict
    :param configurationProperties: The configuration properties for the custom action.
            Note
            You can refer to a name in the configuration properties of the custom action within the URL templates by following the format of {Config:name}, as long as the configuration property is both required and not secret. For more information, see Create a Custom Action for a Pipeline .
            (dict) --Represents information about an action configuration property.
            name (string) -- [REQUIRED]The name of the action configuration property.
            required (boolean) -- [REQUIRED]Whether the configuration property is a required value.
            key (boolean) -- [REQUIRED]Whether the configuration property is a key.
            secret (boolean) -- [REQUIRED]Whether the configuration property is secret. Secrets are hidden from all calls except for GetJobDetails, GetThirdPartyJobDetails, PollForJobs, and PollForThirdPartyJobs.
            When updating a pipeline, passing * * * * * without changing any other values of the action will preserve the prior value of the secret.
            queryable (boolean) --Indicates that the proprety will be used in conjunction with PollForJobs. When creating a custom action, an action can have up to one queryable property. If it has one, that property must be both required and not secret.
            If you create a pipeline with a custom action type, and that custom action contains a queryable property, the value for that configuration property is subject to additional restrictions. The value must be less than or equal to twenty (20) characters. The value can contain only alphanumeric characters, underscores, and hyphens.
            description (string) --The description of the action configuration property that will be displayed to users.
            type (string) --The type of the configuration property.
            
            
    :type configurationProperties: list
    :param inputArtifactDetails: [REQUIRED]
            Returns information about the details of an artifact.
            minimumCount (integer) -- [REQUIRED]The minimum number of artifacts allowed for the action type.
            maximumCount (integer) -- [REQUIRED]The maximum number of artifacts allowed for the action type.
            
    :type inputArtifactDetails: dict
    :param outputArtifactDetails: [REQUIRED]
            Returns information about the details of an artifact.
            minimumCount (integer) -- [REQUIRED]The minimum number of artifacts allowed for the action type.
            maximumCount (integer) -- [REQUIRED]The maximum number of artifacts allowed for the action type.
            
    :type outputArtifactDetails: dict
    """
    pass

def create_pipeline(pipeline=None):
    """
    :param pipeline: [REQUIRED]
            Represents the structure of actions and stages to be performed in the pipeline.
            name (string) -- [REQUIRED]The name of the action to be performed.
            roleArn (string) -- [REQUIRED]The Amazon Resource Name (ARN) for AWS CodePipeline to use to either perform actions with no actionRoleArn, or to use to assume roles for actions with an actionRoleArn.
            artifactStore (dict) -- [REQUIRED]The Amazon S3 location where artifacts are stored for the pipeline. If this Amazon S3 bucket is created manually, it must meet the requirements for AWS CodePipeline. For more information, see the Concepts .
            type (string) -- [REQUIRED]The type of the artifact store, such as S3.
            location (string) -- [REQUIRED]The location for storing the artifacts for a pipeline, such as an S3 bucket or folder.
            encryptionKey (dict) --The encryption key used to encrypt the data in the artifact store, such as an AWS Key Management Service (AWS KMS) key. If this is undefined, the default key for Amazon S3 is used.
            id (string) -- [REQUIRED]The ID used to identify the key. For an AWS KMS key, this is the key ID or key ARN.
            type (string) -- [REQUIRED]The type of encryption key, such as an AWS Key Management Service (AWS KMS) key. When creating or updating a pipeline, the value must be set to 'KMS'.
            
            stages (list) -- [REQUIRED]The stage in which to perform the action.
            (dict) --Represents information about a stage and its definition.
            name (string) -- [REQUIRED]The name of the stage.
            blockers (list) --Reserved for future use.
            (dict) --Reserved for future use.
            name (string) -- [REQUIRED]Reserved for future use.
            type (string) -- [REQUIRED]Reserved for future use.
            
            actions (list) -- [REQUIRED]The actions included in a stage.
            (dict) --Represents information about an action declaration.
            name (string) -- [REQUIRED]The action declaration's name.
            actionTypeId (dict) -- [REQUIRED]The configuration information for the action type.
            category (string) -- [REQUIRED]A category defines what kind of action can be taken in the stage, and constrains the provider type for the action. Valid categories are limited to one of the values below.
            owner (string) -- [REQUIRED]The creator of the action being called.
            provider (string) -- [REQUIRED]The provider of the service being called by the action. Valid providers are determined by the action category. For example, an action in the Deploy category type might have a provider of AWS CodeDeploy, which would be specified as CodeDeploy.
            version (string) -- [REQUIRED]A string that identifies the action type.
            runOrder (integer) --The order in which actions are run.
            configuration (dict) --The action declaration's configuration.
            (string) --
            (string) --
            
            outputArtifacts (list) --The name or ID of the result of the action declaration, such as a test or build artifact.
            (dict) --Represents information about the output of an action.
            name (string) -- [REQUIRED]The name of the output of an artifact, such as 'My App'.
            The input artifact of an action must exactly match the output artifact declared in a preceding action, but the input artifact does not have to be the next action in strict sequence from the action that provided the output artifact. Actions in parallel can declare different output artifacts, which are in turn consumed by different following actions.
            Output artifact names must be unique within a pipeline.
            
            inputArtifacts (list) --The name or ID of the artifact consumed by the action, such as a test or build artifact.
            (dict) --Represents information about an artifact to be worked on, such as a test or build artifact.
            name (string) -- [REQUIRED]The name of the artifact to be worked on, for example, 'My App'.
            The input artifact of an action must exactly match the output artifact declared in a preceding action, but the input artifact does not have to be the next action in strict sequence from the action that provided the output artifact. Actions in parallel can declare different output artifacts, which are in turn consumed by different following actions.
            
            roleArn (string) --The ARN of the IAM service role that will perform the declared action. This is assumed through the roleArn for the pipeline.
            
            
            version (integer) --The version number of the pipeline. A new pipeline always has a version number of 1. This number is automatically incremented when a pipeline is updated.
            Return typedict
            ReturnsResponse Syntax{
              'pipeline': {
                'name': 'string',
                'roleArn': 'string',
                'artifactStore': {
                  'type': 'S3',
                  'location': 'string',
                  'encryptionKey': {
                    'id': 'string',
                    'type': 'KMS'
                  }
                },
                'stages': [
                  {
                    'name': 'string',
                    'blockers': [
                      {
                        'name': 'string',
                        'type': 'Schedule'
                      },
                    ],
                    'actions': [
                      {
                        'name': 'string',
                        'actionTypeId': {
                          'category': 'Source'|'Build'|'Deploy'|'Test'|'Invoke'|'Approval',
                          'owner': 'AWS'|'ThirdParty'|'Custom',
                          'provider': 'string',
                          'version': 'string'
                        },
                        'runOrder': 123,
                        'configuration': {
                          'string': 'string'
                        },
                        'outputArtifacts': [
                          {
                            'name': 'string'
                          },
                        ],
                        'inputArtifacts': [
                          {
                            'name': 'string'
                          },
                        ],
                        'roleArn': 'string'
                      },
                    ]
                  },
                ],
                'version': 123
              }
            }
            Response Structure
            (dict) --Represents the output of a create pipeline action.
            pipeline (dict) --Represents the structure of actions and stages to be performed in the pipeline.
            name (string) --The name of the action to be performed.
            roleArn (string) --The Amazon Resource Name (ARN) for AWS CodePipeline to use to either perform actions with no actionRoleArn, or to use to assume roles for actions with an actionRoleArn.
            artifactStore (dict) --The Amazon S3 location where artifacts are stored for the pipeline. If this Amazon S3 bucket is created manually, it must meet the requirements for AWS CodePipeline. For more information, see the Concepts .
            type (string) --The type of the artifact store, such as S3.
            location (string) --The location for storing the artifacts for a pipeline, such as an S3 bucket or folder.
            encryptionKey (dict) --The encryption key used to encrypt the data in the artifact store, such as an AWS Key Management Service (AWS KMS) key. If this is undefined, the default key for Amazon S3 is used.
            id (string) --The ID used to identify the key. For an AWS KMS key, this is the key ID or key ARN.
            type (string) --The type of encryption key, such as an AWS Key Management Service (AWS KMS) key. When creating or updating a pipeline, the value must be set to 'KMS'.
            
            stages (list) --The stage in which to perform the action.
            (dict) --Represents information about a stage and its definition.
            name (string) --The name of the stage.
            blockers (list) --Reserved for future use.
            (dict) --Reserved for future use.
            name (string) --Reserved for future use.
            type (string) --Reserved for future use.
            
            actions (list) --The actions included in a stage.
            (dict) --Represents information about an action declaration.
            name (string) --The action declaration's name.
            actionTypeId (dict) --The configuration information for the action type.
            category (string) --A category defines what kind of action can be taken in the stage, and constrains the provider type for the action. Valid categories are limited to one of the values below.
            owner (string) --The creator of the action being called.
            provider (string) --The provider of the service being called by the action. Valid providers are determined by the action category. For example, an action in the Deploy category type might have a provider of AWS CodeDeploy, which would be specified as CodeDeploy.
            version (string) --A string that identifies the action type.
            runOrder (integer) --The order in which actions are run.
            configuration (dict) --The action declaration's configuration.
            (string) --
            (string) --
            
            outputArtifacts (list) --The name or ID of the result of the action declaration, such as a test or build artifact.
            (dict) --Represents information about the output of an action.
            name (string) --The name of the output of an artifact, such as 'My App'.
            The input artifact of an action must exactly match the output artifact declared in a preceding action, but the input artifact does not have to be the next action in strict sequence from the action that provided the output artifact. Actions in parallel can declare different output artifacts, which are in turn consumed by different following actions.
            Output artifact names must be unique within a pipeline.
            
            inputArtifacts (list) --The name or ID of the artifact consumed by the action, such as a test or build artifact.
            (dict) --Represents information about an artifact to be worked on, such as a test or build artifact.
            name (string) --The name of the artifact to be worked on, for example, 'My App'.
            The input artifact of an action must exactly match the output artifact declared in a preceding action, but the input artifact does not have to be the next action in strict sequence from the action that provided the output artifact. Actions in parallel can declare different output artifacts, which are in turn consumed by different following actions.
            
            roleArn (string) --The ARN of the IAM service role that will perform the declared action. This is assumed through the roleArn for the pipeline.
            
            
            version (integer) --The version number of the pipeline. A new pipeline always has a version number of 1. This number is automatically incremented when a pipeline is updated.
            
            
            
    :type pipeline: dict
    """
    pass

def delete_custom_action_type(category=None, provider=None, version=None):
    """
    :param category: [REQUIRED]
            The category of the custom action that you want to delete, such as source or deploy.
            
    :type category: string
    :param provider: [REQUIRED]
            The provider of the service used in the custom action, such as AWS CodeDeploy.
            
    :type provider: string
    :param version: [REQUIRED]
            The version of the custom action to delete.
            
    :type version: string
    """
    pass

def delete_pipeline(name=None):
    """
    :param name: [REQUIRED]
            The name of the pipeline to be deleted.
            ReturnsNone
            
    :type name: string
    """
    pass

def disable_stage_transition(pipelineName=None, stageName=None, transitionType=None, reason=None):
    """
    :param pipelineName: [REQUIRED]
            The name of the pipeline in which you want to disable the flow of artifacts from one stage to another.
            
    :type pipelineName: string
    :param stageName: [REQUIRED]
            The name of the stage where you want to disable the inbound or outbound transition of artifacts.
            
    :type stageName: string
    :param transitionType: [REQUIRED]
            Specifies whether artifacts will be prevented from transitioning into the stage and being processed by the actions in that stage (inbound), or prevented from transitioning from the stage after they have been processed by the actions in that stage (outbound).
            
    :type transitionType: string
    :param reason: [REQUIRED]
            The reason given to the user why a stage is disabled, such as waiting for manual approval or manual tests. This message is displayed in the pipeline console UI.
            
    :type reason: string
    """
    pass

def enable_stage_transition(pipelineName=None, stageName=None, transitionType=None):
    """
    :param pipelineName: [REQUIRED]
            The name of the pipeline in which you want to enable the flow of artifacts from one stage to another.
            
    :type pipelineName: string
    :param stageName: [REQUIRED]
            The name of the stage where you want to enable the transition of artifacts, either into the stage (inbound) or from that stage to the next stage (outbound).
            
    :type stageName: string
    :param transitionType: [REQUIRED]
            Specifies whether artifacts will be allowed to enter the stage and be processed by the actions in that stage (inbound) or whether already-processed artifacts will be allowed to transition to the next stage (outbound).
            
    :type transitionType: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_job_details(jobId=None):
    """
    :param jobId: [REQUIRED]
            The unique system-generated ID for the job.
            Return typedict
            ReturnsResponse Syntax{
              'jobDetails': {
                'id': 'string',
                'data': {
                  'actionTypeId': {
                    'category': 'Source'|'Build'|'Deploy'|'Test'|'Invoke'|'Approval',
                    'owner': 'AWS'|'ThirdParty'|'Custom',
                    'provider': 'string',
                    'version': 'string'
                  },
                  'actionConfiguration': {
                    'configuration': {
                      'string': 'string'
                    }
                  },
                  'pipelineContext': {
                    'pipelineName': 'string',
                    'stage': {
                      'name': 'string'
                    },
                    'action': {
                      'name': 'string'
                    }
                  },
                  'inputArtifacts': [
                    {
                      'name': 'string',
                      'revision': 'string',
                      'location': {
                        'type': 'S3',
                        's3Location': {
                          'bucketName': 'string',
                          'objectKey': 'string'
                        }
                      }
                    },
                  ],
                  'outputArtifacts': [
                    {
                      'name': 'string',
                      'revision': 'string',
                      'location': {
                        'type': 'S3',
                        's3Location': {
                          'bucketName': 'string',
                          'objectKey': 'string'
                        }
                      }
                    },
                  ],
                  'artifactCredentials': {
                    'accessKeyId': 'string',
                    'secretAccessKey': 'string',
                    'sessionToken': 'string'
                  },
                  'continuationToken': 'string',
                  'encryptionKey': {
                    'id': 'string',
                    'type': 'KMS'
                  }
                },
                'accountId': 'string'
              }
            }
            Response Structure
            (dict) --Represents the output of a get job details action.
            jobDetails (dict) --The details of the job.
            Note
            If AWSSessionCredentials is used, a long-running job can call GetJobDetails again to obtain new credentials.
            id (string) --The unique system-generated ID of the job.
            data (dict) --Represents additional information about a job required for a job worker to complete the job.
            actionTypeId (dict) --Represents information about an action type.
            category (string) --A category defines what kind of action can be taken in the stage, and constrains the provider type for the action. Valid categories are limited to one of the values below.
            owner (string) --The creator of the action being called.
            provider (string) --The provider of the service being called by the action. Valid providers are determined by the action category. For example, an action in the Deploy category type might have a provider of AWS CodeDeploy, which would be specified as CodeDeploy.
            version (string) --A string that identifies the action type.
            actionConfiguration (dict) --Represents information about an action configuration.
            configuration (dict) --The configuration data for the action.
            (string) --
            (string) --
            
            pipelineContext (dict) --Represents information about a pipeline to a job worker.
            pipelineName (string) --The name of the pipeline. This is a user-specified value. Pipeline names must be unique across all pipeline names under an Amazon Web Services account.
            stage (dict) --The stage of the pipeline.
            name (string) --The name of the stage.
            action (dict) --Represents the context of an action within the stage of a pipeline to a job worker.
            name (string) --The name of the action within the context of a job.
            
            inputArtifacts (list) --The artifact supplied to the job.
            (dict) --Represents information about an artifact that will be worked upon by actions in the pipeline.
            name (string) --The artifact's name.
            revision (string) --The artifact's revision ID. Depending on the type of object, this could be a commit ID (GitHub) or a revision ID (Amazon S3).
            location (dict) --The location of an artifact.
            type (string) --The type of artifact in the location.
            s3Location (dict) --The Amazon S3 bucket that contains the artifact.
            bucketName (string) --The name of the Amazon S3 bucket.
            objectKey (string) --The key of the object in the Amazon S3 bucket, which uniquely identifies the object in the bucket.
            
            
            outputArtifacts (list) --The output of the job.
            (dict) --Represents information about an artifact that will be worked upon by actions in the pipeline.
            name (string) --The artifact's name.
            revision (string) --The artifact's revision ID. Depending on the type of object, this could be a commit ID (GitHub) or a revision ID (Amazon S3).
            location (dict) --The location of an artifact.
            type (string) --The type of artifact in the location.
            s3Location (dict) --The Amazon S3 bucket that contains the artifact.
            bucketName (string) --The name of the Amazon S3 bucket.
            objectKey (string) --The key of the object in the Amazon S3 bucket, which uniquely identifies the object in the bucket.
            
            
            artifactCredentials (dict) --Represents an AWS session credentials object. These credentials are temporary credentials that are issued by AWS Secure Token Service (STS). They can be used to access input and output artifacts in the Amazon S3 bucket used to store artifact for the pipeline in AWS CodePipeline.
            accessKeyId (string) --The access key for the session.
            secretAccessKey (string) --The secret access key for the session.
            sessionToken (string) --The token for the session.
            continuationToken (string) --A system-generated token, such as a AWS CodeDeploy deployment ID, that a job requires in order to continue the job asynchronously.
            encryptionKey (dict) --Represents information about the key used to encrypt data in the artifact store, such as an AWS Key Management Service (AWS KMS) key.
            id (string) --The ID used to identify the key. For an AWS KMS key, this is the key ID or key ARN.
            type (string) --The type of encryption key, such as an AWS Key Management Service (AWS KMS) key. When creating or updating a pipeline, the value must be set to 'KMS'.
            
            accountId (string) --The AWS account ID associated with the job.
            
            
            
    :type jobId: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_pipeline(name=None, version=None):
    """
    :param name: [REQUIRED]
            The name of the pipeline for which you want to get information. Pipeline names must be unique under an Amazon Web Services (AWS) user account.
            
    :type name: string
    :param version: The version number of the pipeline. If you do not specify a version, defaults to the most current version.
    :type version: integer
    """
    pass

def get_pipeline_execution(pipelineName=None, pipelineExecutionId=None):
    """
    :param pipelineName: [REQUIRED]
            The name of the pipeline about which you want to get execution details.
            
    :type pipelineName: string
    :param pipelineExecutionId: [REQUIRED]
            The ID of the pipeline execution about which you want to get execution details.
            
    :type pipelineExecutionId: string
    """
    pass

def get_pipeline_state(name=None):
    """
    :param name: [REQUIRED]
            The name of the pipeline about which you want to get information.
            Return typedict
            ReturnsResponse Syntax{
              'pipelineName': 'string',
              'pipelineVersion': 123,
              'stageStates': [
                {
                  'stageName': 'string',
                  'inboundTransitionState': {
                    'enabled': True|False,
                    'lastChangedBy': 'string',
                    'lastChangedAt': datetime(2015, 1, 1),
                    'disabledReason': 'string'
                  },
                  'actionStates': [
                    {
                      'actionName': 'string',
                      'currentRevision': {
                        'revisionId': 'string',
                        'revisionChangeId': 'string',
                        'created': datetime(2015, 1, 1)
                      },
                      'latestExecution': {
                        'status': 'InProgress'|'Succeeded'|'Failed',
                        'summary': 'string',
                        'lastStatusChange': datetime(2015, 1, 1),
                        'token': 'string',
                        'lastUpdatedBy': 'string',
                        'externalExecutionId': 'string',
                        'externalExecutionUrl': 'string',
                        'percentComplete': 123,
                        'errorDetails': {
                          'code': 'string',
                          'message': 'string'
                        }
                      },
                      'entityUrl': 'string',
                      'revisionUrl': 'string'
                    },
                  ],
                  'latestExecution': {
                    'pipelineExecutionId': 'string',
                    'status': 'InProgress'|'Failed'|'Succeeded'
                  }
                },
              ],
              'created': datetime(2015, 1, 1),
              'updated': datetime(2015, 1, 1)
            }
            Response Structure
            (dict) --Represents the output of a get pipeline state action.
            pipelineName (string) --The name of the pipeline for which you want to get the state.
            pipelineVersion (integer) --The version number of the pipeline.
            Note
            A newly-created pipeline is always assigned a version number of 1 .
            stageStates (list) --A list of the pipeline stage output information, including stage name, state, most recent run details, whether the stage is disabled, and other data.
            (dict) --Represents information about the state of the stage.
            stageName (string) --The name of the stage.
            inboundTransitionState (dict) --The state of the inbound transition, which is either enabled or disabled.
            enabled (boolean) --Whether the transition between stages is enabled (true) or disabled (false).
            lastChangedBy (string) --The ID of the user who last changed the transition state.
            lastChangedAt (datetime) --The timestamp when the transition state was last changed.
            disabledReason (string) --The user-specified reason why the transition between two stages of a pipeline was disabled.
            actionStates (list) --The state of the stage.
            (dict) --Represents information about the state of an action.
            actionName (string) --The name of the action.
            currentRevision (dict) --Represents information about the version (or revision) of an action.
            revisionId (string) --The system-generated unique ID that identifies the revision number of the action.
            revisionChangeId (string) --The unique identifier of the change that set the state to this revision, for example a deployment ID or timestamp.
            created (datetime) --The date and time when the most recent version of the action was created, in timestamp format.
            latestExecution (dict) --Represents information about the run of an action.
            status (string) --The status of the action, or for a completed action, the last status of the action.
            summary (string) --A summary of the run of the action.
            lastStatusChange (datetime) --The last status change of the action.
            token (string) --The system-generated token used to identify a unique approval request. The token for each open approval request can be obtained using the GetPipelineState command and is used to validate that the approval request corresponding to this token is still valid.
            lastUpdatedBy (string) --The ARN of the user who last changed the pipeline.
            externalExecutionId (string) --The external ID of the run of the action.
            externalExecutionUrl (string) --The URL of a resource external to AWS that will be used when running the action, for example an external repository URL.
            percentComplete (integer) --A percentage of completeness of the action as it runs.
            errorDetails (dict) --The details of an error returned by a URL external to AWS.
            code (string) --The system ID or error number code of the error.
            message (string) --The text of the error message.
            
            entityUrl (string) --A URL link for more information about the state of the action, such as a deployment group details page.
            revisionUrl (string) --A URL link for more information about the revision, such as a commit details page.
            
            latestExecution (dict) --Information about the latest execution in the stage, including its ID and status.
            pipelineExecutionId (string) --The ID of the pipeline execution associated with the stage.
            status (string) --The status of the stage, or for a completed stage, the last status of the stage.
            
            created (datetime) --The date and time the pipeline was created, in timestamp format.
            updated (datetime) --The date and time the pipeline was last updated, in timestamp format.
            
            
    :type name: string
    """
    pass

def get_third_party_job_details(jobId=None, clientToken=None):
    """
    :param jobId: [REQUIRED]
            The unique system-generated ID used for identifying the job.
            
    :type jobId: string
    :param clientToken: [REQUIRED]
            The clientToken portion of the clientId and clientToken pair used to verify that the calling entity is allowed access to the job and its details.
            
    :type clientToken: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_action_types(actionOwnerFilter=None, nextToken=None):
    """
    :param actionOwnerFilter: Filters the list of action types to those created by a specified entity.
    :type actionOwnerFilter: string
    :param nextToken: An identifier that was returned from the previous list action types call, which can be used to return the next set of action types in the list.
    :type nextToken: string
    """
    pass

def list_pipelines(nextToken=None):
    """
    :param nextToken: An identifier that was returned from the previous list pipelines call, which can be used to return the next set of pipelines in the list.
            Return typedict
            ReturnsResponse Syntax{
              'pipelines': [
                {
                  'name': 'string',
                  'version': 123,
                  'created': datetime(2015, 1, 1),
                  'updated': datetime(2015, 1, 1)
                },
              ],
              'nextToken': 'string'
            }
            Response Structure
            (dict) --Represents the output of a list pipelines action.
            pipelines (list) --The list of pipelines.
            (dict) --Returns a summary of a pipeline.
            name (string) --The name of the pipeline.
            version (integer) --The version number of the pipeline.
            created (datetime) --The date and time the pipeline was created, in timestamp format.
            updated (datetime) --The date and time of the last update to the pipeline, in timestamp format.
            
            nextToken (string) --If the amount of returned information is significantly large, an identifier is also returned which can be used in a subsequent list pipelines call to return the next set of pipelines in the list.
            
            
    :type nextToken: string
    """
    pass

def poll_for_jobs(actionTypeId=None, maxBatchSize=None, queryParam=None):
    """
    :param actionTypeId: [REQUIRED]
            Represents information about an action type.
            category (string) -- [REQUIRED]A category defines what kind of action can be taken in the stage, and constrains the provider type for the action. Valid categories are limited to one of the values below.
            owner (string) -- [REQUIRED]The creator of the action being called.
            provider (string) -- [REQUIRED]The provider of the service being called by the action. Valid providers are determined by the action category. For example, an action in the Deploy category type might have a provider of AWS CodeDeploy, which would be specified as CodeDeploy.
            version (string) -- [REQUIRED]A string that identifies the action type.
            
    :type actionTypeId: dict
    :param maxBatchSize: The maximum number of jobs to return in a poll for jobs call.
    :type maxBatchSize: integer
    :param queryParam: A map of property names and values. For an action type with no queryable properties, this value must be null or an empty map. For an action type with a queryable property, you must supply that property as a key in the map. Only jobs whose action configuration matches the mapped value will be returned.
            (string) --
            (string) --
            
    :type queryParam: dict
    """
    pass

def poll_for_third_party_jobs(actionTypeId=None, maxBatchSize=None):
    """
    :param actionTypeId: [REQUIRED]
            Represents information about an action type.
            category (string) -- [REQUIRED]A category defines what kind of action can be taken in the stage, and constrains the provider type for the action. Valid categories are limited to one of the values below.
            owner (string) -- [REQUIRED]The creator of the action being called.
            provider (string) -- [REQUIRED]The provider of the service being called by the action. Valid providers are determined by the action category. For example, an action in the Deploy category type might have a provider of AWS CodeDeploy, which would be specified as CodeDeploy.
            version (string) -- [REQUIRED]A string that identifies the action type.
            
    :type actionTypeId: dict
    :param maxBatchSize: The maximum number of jobs to return in a poll for jobs call.
    :type maxBatchSize: integer
    """
    pass

def put_action_revision(pipelineName=None, stageName=None, actionName=None, actionRevision=None):
    """
    :param pipelineName: [REQUIRED]
            The name of the pipeline that will start processing the revision to the source.
            
    :type pipelineName: string
    :param stageName: [REQUIRED]
            The name of the stage that contains the action that will act upon the revision.
            
    :type stageName: string
    :param actionName: [REQUIRED]
            The name of the action that will process the revision.
            
    :type actionName: string
    :param actionRevision: [REQUIRED]
            Represents information about the version (or revision) of an action.
            revisionId (string) -- [REQUIRED]The system-generated unique ID that identifies the revision number of the action.
            revisionChangeId (string) -- [REQUIRED]The unique identifier of the change that set the state to this revision, for example a deployment ID or timestamp.
            created (datetime) -- [REQUIRED]The date and time when the most recent version of the action was created, in timestamp format.
            
    :type actionRevision: dict
    """
    pass

def put_approval_result(pipelineName=None, stageName=None, actionName=None, result=None, token=None):
    """
    :param pipelineName: [REQUIRED]
            The name of the pipeline that contains the action.
            
    :type pipelineName: string
    :param stageName: [REQUIRED]
            The name of the stage that contains the action.
            
    :type stageName: string
    :param actionName: [REQUIRED]
            The name of the action for which approval is requested.
            
    :type actionName: string
    :param result: [REQUIRED]
            Represents information about the result of the approval request.
            summary (string) -- [REQUIRED]The summary of the current status of the approval request.
            status (string) -- [REQUIRED]The response submitted by a reviewer assigned to an approval action request.
            
    :type result: dict
    :param token: [REQUIRED]
            The system-generated token used to identify a unique approval request. The token for each open approval request can be obtained using the GetPipelineState action and is used to validate that the approval request corresponding to this token is still valid.
            
    :type token: string
    """
    pass

def put_job_failure_result(jobId=None, failureDetails=None):
    """
    :param jobId: [REQUIRED]
            The unique system-generated ID of the job that failed. This is the same ID returned from PollForJobs.
            
    :type jobId: string
    :param failureDetails: [REQUIRED]
            The details about the failure of a job.
            type (string) -- [REQUIRED]The type of the failure.
            message (string) -- [REQUIRED]The message about the failure.
            externalExecutionId (string) --The external ID of the run of the action that failed.
            
    :type failureDetails: dict
    """
    pass

def put_job_success_result(jobId=None, currentRevision=None, continuationToken=None, executionDetails=None):
    """
    :param jobId: [REQUIRED]
            The unique system-generated ID of the job that succeeded. This is the same ID returned from PollForJobs.
            
    :type jobId: string
    :param currentRevision: The ID of the current revision of the artifact successfully worked upon by the job.
            revision (string) -- [REQUIRED]The revision ID of the current version of an artifact.
            changeIdentifier (string) -- [REQUIRED]The change identifier for the current revision.
            created (datetime) --The date and time when the most recent revision of the artifact was created, in timestamp format.
            revisionSummary (string) --The summary of the most recent revision of the artifact.
            
    :type currentRevision: dict
    :param continuationToken: A token generated by a job worker, such as an AWS CodeDeploy deployment ID, that a successful job provides to identify a custom action in progress. Future jobs will use this token in order to identify the running instance of the action. It can be reused to return additional information about the progress of the custom action. When the action is complete, no continuation token should be supplied.
    :type continuationToken: string
    :param executionDetails: The execution details of the successful job, such as the actions taken by the job worker.
            summary (string) --The summary of the current status of the actions.
            externalExecutionId (string) --The system-generated unique ID of this action used to identify this job worker in any external systems, such as AWS CodeDeploy.
            percentComplete (integer) --The percentage of work completed on the action, represented on a scale of zero to one hundred percent.
            
    :type executionDetails: dict
    """
    pass

def put_third_party_job_failure_result(jobId=None, clientToken=None, failureDetails=None):
    """
    :param jobId: [REQUIRED]
            The ID of the job that failed. This is the same ID returned from PollForThirdPartyJobs.
            
    :type jobId: string
    :param clientToken: [REQUIRED]
            The clientToken portion of the clientId and clientToken pair used to verify that the calling entity is allowed access to the job and its details.
            
    :type clientToken: string
    :param failureDetails: [REQUIRED]
            Represents information about failure details.
            type (string) -- [REQUIRED]The type of the failure.
            message (string) -- [REQUIRED]The message about the failure.
            externalExecutionId (string) --The external ID of the run of the action that failed.
            
    :type failureDetails: dict
    """
    pass

def put_third_party_job_success_result(jobId=None, clientToken=None, currentRevision=None, continuationToken=None, executionDetails=None):
    """
    :param jobId: [REQUIRED]
            The ID of the job that successfully completed. This is the same ID returned from PollForThirdPartyJobs.
            
    :type jobId: string
    :param clientToken: [REQUIRED]
            The clientToken portion of the clientId and clientToken pair used to verify that the calling entity is allowed access to the job and its details.
            
    :type clientToken: string
    :param currentRevision: Represents information about a current revision.
            revision (string) -- [REQUIRED]The revision ID of the current version of an artifact.
            changeIdentifier (string) -- [REQUIRED]The change identifier for the current revision.
            created (datetime) --The date and time when the most recent revision of the artifact was created, in timestamp format.
            revisionSummary (string) --The summary of the most recent revision of the artifact.
            
    :type currentRevision: dict
    :param continuationToken: A token generated by a job worker, such as an AWS CodeDeploy deployment ID, that a successful job provides to identify a partner action in progress. Future jobs will use this token in order to identify the running instance of the action. It can be reused to return additional information about the progress of the partner action. When the action is complete, no continuation token should be supplied.
    :type continuationToken: string
    :param executionDetails: The details of the actions taken and results produced on an artifact as it passes through stages in the pipeline.
            summary (string) --The summary of the current status of the actions.
            externalExecutionId (string) --The system-generated unique ID of this action used to identify this job worker in any external systems, such as AWS CodeDeploy.
            percentComplete (integer) --The percentage of work completed on the action, represented on a scale of zero to one hundred percent.
            
    :type executionDetails: dict
    """
    pass

def retry_stage_execution(pipelineName=None, stageName=None, pipelineExecutionId=None, retryMode=None):
    """
    :param pipelineName: [REQUIRED]
            The name of the pipeline that contains the failed stage.
            
    :type pipelineName: string
    :param stageName: [REQUIRED]
            The name of the failed stage to be retried.
            
    :type stageName: string
    :param pipelineExecutionId: [REQUIRED]
            The ID of the pipeline execution in the failed stage to be retried. Use the GetPipelineState action to retrieve the current pipelineExecutionId of the failed stage
            
    :type pipelineExecutionId: string
    :param retryMode: [REQUIRED]
            The scope of the retry attempt. Currently, the only supported value is FAILED_ACTIONS.
            
    :type retryMode: string
    """
    pass

def start_pipeline_execution(name=None):
    """
    :param name: [REQUIRED]
            The name of the pipeline to start.
            Return typedict
            ReturnsResponse Syntax{
              'pipelineExecutionId': 'string'
            }
            Response Structure
            (dict) --Represents the output of a start pipeline execution action.
            pipelineExecutionId (string) --The unique system-generated ID of the pipeline execution that was started.
            
            
    :type name: string
    """
    pass

def update_pipeline(pipeline=None):
    """
    :param pipeline: [REQUIRED]
            The name of the pipeline to be updated.
            name (string) -- [REQUIRED]The name of the action to be performed.
            roleArn (string) -- [REQUIRED]The Amazon Resource Name (ARN) for AWS CodePipeline to use to either perform actions with no actionRoleArn, or to use to assume roles for actions with an actionRoleArn.
            artifactStore (dict) -- [REQUIRED]The Amazon S3 location where artifacts are stored for the pipeline. If this Amazon S3 bucket is created manually, it must meet the requirements for AWS CodePipeline. For more information, see the Concepts .
            type (string) -- [REQUIRED]The type of the artifact store, such as S3.
            location (string) -- [REQUIRED]The location for storing the artifacts for a pipeline, such as an S3 bucket or folder.
            encryptionKey (dict) --The encryption key used to encrypt the data in the artifact store, such as an AWS Key Management Service (AWS KMS) key. If this is undefined, the default key for Amazon S3 is used.
            id (string) -- [REQUIRED]The ID used to identify the key. For an AWS KMS key, this is the key ID or key ARN.
            type (string) -- [REQUIRED]The type of encryption key, such as an AWS Key Management Service (AWS KMS) key. When creating or updating a pipeline, the value must be set to 'KMS'.
            
            stages (list) -- [REQUIRED]The stage in which to perform the action.
            (dict) --Represents information about a stage and its definition.
            name (string) -- [REQUIRED]The name of the stage.
            blockers (list) --Reserved for future use.
            (dict) --Reserved for future use.
            name (string) -- [REQUIRED]Reserved for future use.
            type (string) -- [REQUIRED]Reserved for future use.
            
            actions (list) -- [REQUIRED]The actions included in a stage.
            (dict) --Represents information about an action declaration.
            name (string) -- [REQUIRED]The action declaration's name.
            actionTypeId (dict) -- [REQUIRED]The configuration information for the action type.
            category (string) -- [REQUIRED]A category defines what kind of action can be taken in the stage, and constrains the provider type for the action. Valid categories are limited to one of the values below.
            owner (string) -- [REQUIRED]The creator of the action being called.
            provider (string) -- [REQUIRED]The provider of the service being called by the action. Valid providers are determined by the action category. For example, an action in the Deploy category type might have a provider of AWS CodeDeploy, which would be specified as CodeDeploy.
            version (string) -- [REQUIRED]A string that identifies the action type.
            runOrder (integer) --The order in which actions are run.
            configuration (dict) --The action declaration's configuration.
            (string) --
            (string) --
            
            outputArtifacts (list) --The name or ID of the result of the action declaration, such as a test or build artifact.
            (dict) --Represents information about the output of an action.
            name (string) -- [REQUIRED]The name of the output of an artifact, such as 'My App'.
            The input artifact of an action must exactly match the output artifact declared in a preceding action, but the input artifact does not have to be the next action in strict sequence from the action that provided the output artifact. Actions in parallel can declare different output artifacts, which are in turn consumed by different following actions.
            Output artifact names must be unique within a pipeline.
            
            inputArtifacts (list) --The name or ID of the artifact consumed by the action, such as a test or build artifact.
            (dict) --Represents information about an artifact to be worked on, such as a test or build artifact.
            name (string) -- [REQUIRED]The name of the artifact to be worked on, for example, 'My App'.
            The input artifact of an action must exactly match the output artifact declared in a preceding action, but the input artifact does not have to be the next action in strict sequence from the action that provided the output artifact. Actions in parallel can declare different output artifacts, which are in turn consumed by different following actions.
            
            roleArn (string) --The ARN of the IAM service role that will perform the declared action. This is assumed through the roleArn for the pipeline.
            
            
            version (integer) --The version number of the pipeline. A new pipeline always has a version number of 1. This number is automatically incremented when a pipeline is updated.
            Return typedict
            ReturnsResponse Syntax{
              'pipeline': {
                'name': 'string',
                'roleArn': 'string',
                'artifactStore': {
                  'type': 'S3',
                  'location': 'string',
                  'encryptionKey': {
                    'id': 'string',
                    'type': 'KMS'
                  }
                },
                'stages': [
                  {
                    'name': 'string',
                    'blockers': [
                      {
                        'name': 'string',
                        'type': 'Schedule'
                      },
                    ],
                    'actions': [
                      {
                        'name': 'string',
                        'actionTypeId': {
                          'category': 'Source'|'Build'|'Deploy'|'Test'|'Invoke'|'Approval',
                          'owner': 'AWS'|'ThirdParty'|'Custom',
                          'provider': 'string',
                          'version': 'string'
                        },
                        'runOrder': 123,
                        'configuration': {
                          'string': 'string'
                        },
                        'outputArtifacts': [
                          {
                            'name': 'string'
                          },
                        ],
                        'inputArtifacts': [
                          {
                            'name': 'string'
                          },
                        ],
                        'roleArn': 'string'
                      },
                    ]
                  },
                ],
                'version': 123
              }
            }
            Response Structure
            (dict) --Represents the output of an update pipeline action.
            pipeline (dict) --The structure of the updated pipeline.
            name (string) --The name of the action to be performed.
            roleArn (string) --The Amazon Resource Name (ARN) for AWS CodePipeline to use to either perform actions with no actionRoleArn, or to use to assume roles for actions with an actionRoleArn.
            artifactStore (dict) --The Amazon S3 location where artifacts are stored for the pipeline. If this Amazon S3 bucket is created manually, it must meet the requirements for AWS CodePipeline. For more information, see the Concepts .
            type (string) --The type of the artifact store, such as S3.
            location (string) --The location for storing the artifacts for a pipeline, such as an S3 bucket or folder.
            encryptionKey (dict) --The encryption key used to encrypt the data in the artifact store, such as an AWS Key Management Service (AWS KMS) key. If this is undefined, the default key for Amazon S3 is used.
            id (string) --The ID used to identify the key. For an AWS KMS key, this is the key ID or key ARN.
            type (string) --The type of encryption key, such as an AWS Key Management Service (AWS KMS) key. When creating or updating a pipeline, the value must be set to 'KMS'.
            
            stages (list) --The stage in which to perform the action.
            (dict) --Represents information about a stage and its definition.
            name (string) --The name of the stage.
            blockers (list) --Reserved for future use.
            (dict) --Reserved for future use.
            name (string) --Reserved for future use.
            type (string) --Reserved for future use.
            
            actions (list) --The actions included in a stage.
            (dict) --Represents information about an action declaration.
            name (string) --The action declaration's name.
            actionTypeId (dict) --The configuration information for the action type.
            category (string) --A category defines what kind of action can be taken in the stage, and constrains the provider type for the action. Valid categories are limited to one of the values below.
            owner (string) --The creator of the action being called.
            provider (string) --The provider of the service being called by the action. Valid providers are determined by the action category. For example, an action in the Deploy category type might have a provider of AWS CodeDeploy, which would be specified as CodeDeploy.
            version (string) --A string that identifies the action type.
            runOrder (integer) --The order in which actions are run.
            configuration (dict) --The action declaration's configuration.
            (string) --
            (string) --
            
            outputArtifacts (list) --The name or ID of the result of the action declaration, such as a test or build artifact.
            (dict) --Represents information about the output of an action.
            name (string) --The name of the output of an artifact, such as 'My App'.
            The input artifact of an action must exactly match the output artifact declared in a preceding action, but the input artifact does not have to be the next action in strict sequence from the action that provided the output artifact. Actions in parallel can declare different output artifacts, which are in turn consumed by different following actions.
            Output artifact names must be unique within a pipeline.
            
            inputArtifacts (list) --The name or ID of the artifact consumed by the action, such as a test or build artifact.
            (dict) --Represents information about an artifact to be worked on, such as a test or build artifact.
            name (string) --The name of the artifact to be worked on, for example, 'My App'.
            The input artifact of an action must exactly match the output artifact declared in a preceding action, but the input artifact does not have to be the next action in strict sequence from the action that provided the output artifact. Actions in parallel can declare different output artifacts, which are in turn consumed by different following actions.
            
            roleArn (string) --The ARN of the IAM service role that will perform the declared action. This is assumed through the roleArn for the pipeline.
            
            
            version (integer) --The version number of the pipeline. A new pipeline always has a version number of 1. This number is automatically incremented when a pipeline is updated.
            
            
            
    :type pipeline: dict
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_permission(FunctionName=None, StatementId=None, Action=None, Principal=None, SourceArn=None, SourceAccount=None, EventSourceToken=None, Qualifier=None):
    """
    :param FunctionName: [REQUIRED]
            Name of the Lambda function whose resource policy you are updating by adding a new permission.
            You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param StatementId: [REQUIRED]
            A unique statement identifier.
            
    :type StatementId: string
    :param Action: [REQUIRED]
            The AWS Lambda action you want to allow in this statement. Each Lambda action is a string starting with lambda: followed by the API name . For example, lambda:CreateFunction . You can use wildcard (lambda:* ) to grant permission for all AWS Lambda actions.
            
    :type Action: string
    :param Principal: [REQUIRED]
            The principal who is getting this permission. It can be Amazon S3 service Principal (s3.amazonaws.com ) if you want Amazon S3 to invoke the function, an AWS account ID if you are granting cross-account permission, or any valid AWS service principal such as sns.amazonaws.com . For example, you might want to allow a custom application in another AWS account to push events to AWS Lambda by invoking your function.
            
    :type Principal: string
    :param SourceArn: This is optional; however, when granting Amazon S3 permission to invoke your function, you should specify this field with the Amazon Resource Name (ARN) as its value. This ensures that only events generated from the specified source can invoke the function.
            Warning
            If you add a permission for the Amazon S3 principal without providing the source ARN, any AWS account that creates a mapping to your function ARN can send events to invoke your Lambda function from Amazon S3.
            
    :type SourceArn: string
    :param SourceAccount: This parameter is used for S3 and SES only. The AWS account ID (without a hyphen) of the source owner. For example, if the SourceArn identifies a bucket, then this is the bucket owner's account ID. You can use this additional condition to ensure the bucket you specify is owned by a specific account (it is possible the bucket owner deleted the bucket and some other AWS account created the bucket). You can also use this condition to specify all sources (that is, you don't specify the SourceArn ) owned by a specific account.
    :type SourceAccount: string
    :param EventSourceToken: A unique token that must be supplied by the principal invoking the function. This is currently only used for Alexa Smart Home functions.
    :type EventSourceToken: string
    :param Qualifier: You can use this optional query parameter to describe a qualified ARN using a function version or an alias name. The permission will then apply to the specific qualified ARN. For example, if you specify function version 2 as the qualifier, then permission applies only when request is made using qualified function ARN:
            arn:aws:lambda:aws-region:acct-id:function:function-name:2
            If you specify an alias name, for example PROD , then the permission is valid only for requests made using the alias ARN:
            arn:aws:lambda:aws-region:acct-id:function:function-name:PROD
            If the qualifier is not specified, the permission is valid only when requests is made using unqualified function ARN.
            arn:aws:lambda:aws-region:acct-id:function:function-name
            
    :type Qualifier: string
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_alias(FunctionName=None, Name=None, FunctionVersion=None, Description=None):
    """
    :param FunctionName: [REQUIRED]
            Name of the Lambda function for which you want to create an alias.
            
    :type FunctionName: string
    :param Name: [REQUIRED]
            Name for the alias you are creating.
            
    :type Name: string
    :param FunctionVersion: [REQUIRED]
            Lambda function version for which you are creating the alias.
            
    :type FunctionVersion: string
    :param Description: Description of the alias.
    :type Description: string
    """
    pass

def create_event_source_mapping(EventSourceArn=None, FunctionName=None, Enabled=None, BatchSize=None, StartingPosition=None):
    """
    :param EventSourceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the Amazon Kinesis or the Amazon DynamoDB stream that is the event source. Any record added to this stream could cause AWS Lambda to invoke your Lambda function, it depends on the BatchSize . AWS Lambda POSTs the Amazon Kinesis event, containing records, to your Lambda function as JSON.
            
    :type EventSourceArn: string
    :param FunctionName: [REQUIRED]
            The Lambda function to invoke when AWS Lambda detects an event on the stream.
            You can specify the function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ).
            If you are using versioning, you can also provide a qualified function ARN (ARN that is qualified with function version or alias name as suffix). For more information about versioning, see AWS Lambda Function Versioning and Aliases
            AWS Lambda also allows you to specify only the function name with the account ID qualifier (for example, account-id:Thumbnail ).
            Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Enabled: Indicates whether AWS Lambda should begin polling the event source. By default, Enabled is true.
    :type Enabled: boolean
    :param BatchSize: The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records. The default is 100 records.
    :type BatchSize: integer
    :param StartingPosition: [REQUIRED]
            The position in the stream where AWS Lambda should start reading. For more information, go to ShardIteratorType in the Amazon Kinesis API Reference .
            
    :type StartingPosition: string
    """
    pass

def create_function(FunctionName=None, Runtime=None, Role=None, Handler=None, Code=None, Description=None, Timeout=None, MemorySize=None, Publish=None, VpcConfig=None):
    """
    :param FunctionName: [REQUIRED]
            The name you want to assign to the function you are uploading. The function names appear in the console and are returned in the ListFunctions API. Function names are used to specify functions to other AWS Lambda APIs, such as Invoke .
            
    :type FunctionName: string
    :param Runtime: [REQUIRED]
            The runtime environment for the Lambda function you are uploading.
            To use the Node.js runtime v4.3, set the value to 'nodejs4.3'. To use earlier runtime (v0.10.42), set the value to 'nodejs'.
            
    :type Runtime: string
    :param Role: [REQUIRED]
            The Amazon Resource Name (ARN) of the IAM role that Lambda assumes when it executes your function to access any other Amazon Web Services (AWS) resources. For more information, see AWS Lambda: How it Works .
            
    :type Role: string
    :param Handler: [REQUIRED]
            The function within your code that Lambda calls to begin execution. For Node.js, it is the module-name .*export* value in your function. For Java, it can be package.class-name::handler or package.class-name . For more information, see Lambda Function Handler (Java) .
            
    :type Handler: string
    :param Code: [REQUIRED]
            The code for the Lambda function.
            ZipFile (bytes) --The contents of your zip file containing your deployment package. If you are using the web API directly, the contents of the zip file must be base64-encoded. If you are using the AWS SDKs or the AWS CLI, the SDKs or CLI will do the encoding for you. For more information about creating a .zip file, go to Execution Permissions in the AWS Lambda Developer Guide .
            S3Bucket (string) --Amazon S3 bucket name where the .zip file containing your deployment package is stored. This bucket must reside in the same AWS region where you are creating the Lambda function.
            S3Key (string) --The Amazon S3 object (the deployment package) key name you want to upload.
            S3ObjectVersion (string) --The Amazon S3 object (the deployment package) version you want to upload.
            
    :type Code: dict
    :param Description: A short, user-defined function description. Lambda does not use this value. Assign a meaningful description as you see fit.
    :type Description: string
    :param Timeout: The function execution time at which Lambda should terminate the function. Because the execution time has cost implications, we recommend you set this value based on your expected execution time. The default is 3 seconds.
    :type Timeout: integer
    :param MemorySize: The amount of memory, in MB, your Lambda function is given. Lambda uses this memory size to infer the amount of CPU and memory allocated to your function. Your function use-case determines your CPU and memory requirements. For example, a database operation might need less memory compared to an image processing function. The default value is 128 MB. The value must be a multiple of 64 MB.
    :type MemorySize: integer
    :param Publish: This boolean parameter can be used to request AWS Lambda to create the Lambda function and publish a version as an atomic operation.
    :type Publish: boolean
    :param VpcConfig: If your Lambda function accesses resources in a VPC, you provide this parameter identifying the list of security group IDs and subnet IDs. These must belong to the same VPC. You must provide at least one security group and one subnet ID.
            SubnetIds (list) --A list of one or more subnet IDs in your VPC.
            (string) --
            SecurityGroupIds (list) --A list of one or more security groups IDs in your VPC.
            (string) --
            
    :type VpcConfig: dict
    """
    pass

def delete_alias(FunctionName=None, Name=None):
    """
    :param FunctionName: [REQUIRED]
            The Lambda function name for which the alias is created. Deleting an alias does not delete the function version to which it is pointing.
            
    :type FunctionName: string
    :param Name: [REQUIRED]
            Name of the alias to delete.
            
    :type Name: string
    """
    pass

def delete_event_source_mapping(UUID=None):
    """
    :param UUID: [REQUIRED]
            The event source mapping ID.
            Return typedict
            ReturnsResponse Syntax{
              'UUID': 'string',
              'BatchSize': 123,
              'EventSourceArn': 'string',
              'FunctionArn': 'string',
              'LastModified': datetime(2015, 1, 1),
              'LastProcessingResult': 'string',
              'State': 'string',
              'StateTransitionReason': 'string'
            }
            Response Structure
            (dict) --Describes mapping between an Amazon Kinesis stream and a Lambda function.
            UUID (string) --The AWS Lambda assigned opaque identifier for the mapping.
            BatchSize (integer) --The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records.
            EventSourceArn (string) --The Amazon Resource Name (ARN) of the Amazon Kinesis stream that is the source of events.
            FunctionArn (string) --The Lambda function to invoke when AWS Lambda detects an event on the stream.
            LastModified (datetime) --The UTC time string indicating the last time the event mapping was updated.
            LastProcessingResult (string) --The result of the last AWS Lambda invocation of your Lambda function.
            State (string) --The state of the event source mapping. It can be Creating , Enabled , Disabled , Enabling , Disabling , Updating , or Deleting .
            StateTransitionReason (string) --The reason the event source mapping is in its current state. It is either user-requested or an AWS Lambda-initiated state transition.
            
            
    :type UUID: string
    """
    pass

def delete_function(FunctionName=None, Qualifier=None):
    """
    :param FunctionName: [REQUIRED]
            The Lambda function to delete.
            You can specify the function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). If you are using versioning, you can also provide a qualified function ARN (ARN that is qualified with function version or alias name as suffix). AWS Lambda also allows you to specify only the function name with the account ID qualifier (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Qualifier: Using this optional parameter you can specify a function version (but not the $LATEST version) to direct AWS Lambda to delete a specific function version. If the function version has one or more aliases pointing to it, you will get an error because you cannot have aliases pointing to it. You can delete any function version but not the $LATEST , that is, you cannot specify $LATEST as the value of this parameter. The $LATEST version can be deleted only when you want to delete all the function versions and aliases.
            You can only specify a function version, not an alias name, using this parameter. You cannot delete a function version using its alias.
            If you don't specify this parameter, AWS Lambda will delete the function, including all of its versions and aliases.
            
    :type Qualifier: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_alias(FunctionName=None, Name=None):
    """
    :param FunctionName: [REQUIRED]
            Function name for which the alias is created. An alias is a subresource that exists only in the context of an existing Lambda function so you must specify the function name.
            
    :type FunctionName: string
    :param Name: [REQUIRED]
            Name of the alias for which you want to retrieve information.
            
    :type Name: string
    """
    pass

def get_event_source_mapping(UUID=None):
    """
    :param UUID: [REQUIRED]
            The AWS Lambda assigned ID of the event source mapping.
            Return typedict
            ReturnsResponse Syntax{
              'UUID': 'string',
              'BatchSize': 123,
              'EventSourceArn': 'string',
              'FunctionArn': 'string',
              'LastModified': datetime(2015, 1, 1),
              'LastProcessingResult': 'string',
              'State': 'string',
              'StateTransitionReason': 'string'
            }
            Response Structure
            (dict) --Describes mapping between an Amazon Kinesis stream and a Lambda function.
            UUID (string) --The AWS Lambda assigned opaque identifier for the mapping.
            BatchSize (integer) --The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records.
            EventSourceArn (string) --The Amazon Resource Name (ARN) of the Amazon Kinesis stream that is the source of events.
            FunctionArn (string) --The Lambda function to invoke when AWS Lambda detects an event on the stream.
            LastModified (datetime) --The UTC time string indicating the last time the event mapping was updated.
            LastProcessingResult (string) --The result of the last AWS Lambda invocation of your Lambda function.
            State (string) --The state of the event source mapping. It can be Creating , Enabled , Disabled , Enabling , Disabling , Updating , or Deleting .
            StateTransitionReason (string) --The reason the event source mapping is in its current state. It is either user-requested or an AWS Lambda-initiated state transition.
            
            
    :type UUID: string
    """
    pass

def get_function(FunctionName=None, Qualifier=None):
    """
    :param FunctionName: [REQUIRED]
            The Lambda function name.
            You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Qualifier: Using this optional parameter to specify a function version or an alias name. If you specify function version, the API uses qualified function ARN for the request and returns information about the specific Lambda function version. If you specify an alias name, the API uses the alias ARN and returns information about the function version to which the alias points. If you don't provide this parameter, the API uses unqualified function ARN and returns information about the $LATEST version of the Lambda function.
    :type Qualifier: string
    """
    pass

def get_function_configuration(FunctionName=None, Qualifier=None):
    """
    :param FunctionName: [REQUIRED]
            The name of the Lambda function for which you want to retrieve the configuration information.
            You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Qualifier: Using this optional parameter you can specify a function version or an alias name. If you specify function version, the API uses qualified function ARN and returns information about the specific function version. If you specify an alias name, the API uses the alias ARN and returns information about the function version to which the alias points.
            If you don't specify this parameter, the API uses unqualified function ARN, and returns information about the $LATEST function version.
            
    :type Qualifier: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_policy(FunctionName=None, Qualifier=None):
    """
    :param FunctionName: [REQUIRED]
            Function name whose resource policy you want to retrieve.
            You can specify the function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). If you are using versioning, you can also provide a qualified function ARN (ARN that is qualified with function version or alias name as suffix). AWS Lambda also allows you to specify only the function name with the account ID qualifier (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Qualifier: You can specify this optional query parameter to specify a function version or an alias name in which case this API will return all permissions associated with the specific qualified ARN. If you don't provide this parameter, the API will return permissions that apply to the unqualified function ARN.
    :type Qualifier: string
    """
    pass

def get_waiter():
    """
    """
    pass

def invoke(FunctionName=None, InvocationType=None, LogType=None, ClientContext=None, Payload=None, Qualifier=None):
    """
    :param FunctionName: [REQUIRED]
            The Lambda function name.
            You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param InvocationType: By default, the Invoke API assumes RequestResponse invocation type. You can optionally request asynchronous execution by specifying Event as the InvocationType . You can also use this parameter to request AWS Lambda to not execute the function but do some verification, such as if the caller is authorized to invoke the function and if the inputs are valid. You request this by specifying DryRun as the InvocationType . This is useful in a cross-account scenario when you want to verify access to a function without running it.
    :type InvocationType: string
    :param LogType: You can set this optional parameter to Tail in the request only if you specify the InvocationType parameter with value RequestResponse . In this case, AWS Lambda returns the base64-encoded last 4 KB of log data produced by your Lambda function in the x-amz-log-result header.
    :type LogType: string
    :param ClientContext: Using the ClientContext you can pass client-specific information to the Lambda function you are invoking. You can then process the client information in your Lambda function as you choose through the context variable. For an example of a ClientContext JSON, see PutEvents in the Amazon Mobile Analytics API Reference and User Guide .
            The ClientContext JSON must be base64-encoded.
            
    :type ClientContext: string
    :param Payload: JSON that you want to provide to your Lambda function as input.
    :type Payload: bytes or seekable file-like object
    :param Qualifier: You can use this optional parameter to specify a Lambda function version or alias name. If you specify a function version, the API uses the qualified function ARN to invoke a specific Lambda function. If you specify an alias name, the API uses the alias ARN to invoke the Lambda function version to which the alias points.
            If you don't provide this parameter, then the API uses unqualified function ARN which results in invocation of the $LATEST version.
            
    :type Qualifier: string
    """
    pass

def invoke_async(FunctionName=None, InvokeArgs=None):
    """
    :param FunctionName: [REQUIRED]
            The Lambda function name.
            
    :type FunctionName: string
    :param InvokeArgs: [REQUIRED]
            JSON that you want to provide to your Lambda function as input.
            
    :type InvokeArgs: bytes or seekable file-like object
    """
    pass

def list_aliases(FunctionName=None, FunctionVersion=None, Marker=None, MaxItems=None):
    """
    :param FunctionName: [REQUIRED]
            Lambda function name for which the alias is created.
            
    :type FunctionName: string
    :param FunctionVersion: If you specify this optional parameter, the API returns only the aliases that are pointing to the specific Lambda function version, otherwise the API returns all of the aliases created for the Lambda function.
    :type FunctionVersion: string
    :param Marker: Optional string. An opaque pagination token returned from a previous ListAliases operation. If present, indicates where to continue the listing.
    :type Marker: string
    :param MaxItems: Optional integer. Specifies the maximum number of aliases to return in response. This parameter value must be greater than 0.
    :type MaxItems: integer
    """
    pass

def list_event_source_mappings(EventSourceArn=None, FunctionName=None, Marker=None, MaxItems=None):
    """
    :param EventSourceArn: The Amazon Resource Name (ARN) of the Amazon Kinesis stream. (This parameter is optional.)
    :type EventSourceArn: string
    :param FunctionName: The name of the Lambda function.
            You can specify the function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). If you are using versioning, you can also provide a qualified function ARN (ARN that is qualified with function version or alias name as suffix). AWS Lambda also allows you to specify only the function name with the account ID qualifier (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Marker: Optional string. An opaque pagination token returned from a previous ListEventSourceMappings operation. If present, specifies to continue the list from where the returning call left off.
    :type Marker: string
    :param MaxItems: Optional integer. Specifies the maximum number of event sources to return in response. This value must be greater than 0.
    :type MaxItems: integer
    """
    pass

def list_functions(Marker=None, MaxItems=None):
    """
    :param Marker: Optional string. An opaque pagination token returned from a previous ListFunctions operation. If present, indicates where to continue the listing.
    :type Marker: string
    :param MaxItems: Optional integer. Specifies the maximum number of AWS Lambda functions to return in response. This parameter value must be greater than 0.
    :type MaxItems: integer
    """
    pass

def list_versions_by_function(FunctionName=None, Marker=None, MaxItems=None):
    """
    :param FunctionName: [REQUIRED]
            Function name whose versions to list. You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Marker: Optional string. An opaque pagination token returned from a previous ListVersionsByFunction operation. If present, indicates where to continue the listing.
    :type Marker: string
    :param MaxItems: Optional integer. Specifies the maximum number of AWS Lambda function versions to return in response. This parameter value must be greater than 0.
    :type MaxItems: integer
    """
    pass

def publish_version(FunctionName=None, CodeSha256=None, Description=None):
    """
    :param FunctionName: [REQUIRED]
            The Lambda function name. You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param CodeSha256: The SHA256 hash of the deployment package you want to publish. This provides validation on the code you are publishing. If you provide this parameter value must match the SHA256 of the $LATEST version for the publication to succeed.
    :type CodeSha256: string
    :param Description: The description for the version you are publishing. If not provided, AWS Lambda copies the description from the $LATEST version.
    :type Description: string
    """
    pass

def remove_permission(FunctionName=None, StatementId=None, Qualifier=None):
    """
    :param FunctionName: [REQUIRED]
            Lambda function whose resource policy you want to remove a permission from.
            You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param StatementId: [REQUIRED]
            Statement ID of the permission to remove.
            
    :type StatementId: string
    :param Qualifier: You can specify this optional parameter to remove permission associated with a specific function version or function alias. If you don't specify this parameter, the API removes permission associated with the unqualified function ARN.
    :type Qualifier: string
    """
    pass

def update_alias(FunctionName=None, Name=None, FunctionVersion=None, Description=None):
    """
    :param FunctionName: [REQUIRED]
            The function name for which the alias is created.
            
    :type FunctionName: string
    :param Name: [REQUIRED]
            The alias name.
            
    :type Name: string
    :param FunctionVersion: Using this parameter you can change the Lambda function version to which the alias points.
    :type FunctionVersion: string
    :param Description: You can change the description of the alias using this parameter.
    :type Description: string
    """
    pass

def update_event_source_mapping(UUID=None, FunctionName=None, Enabled=None, BatchSize=None):
    """
    :param UUID: [REQUIRED]
            The event source mapping identifier.
            
    :type UUID: string
    :param FunctionName: The Lambda function to which you want the stream records sent.
            You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ).
            If you are using versioning, you can also provide a qualified function ARN (ARN that is qualified with function version or alias name as suffix). For more information about versioning, see AWS Lambda Function Versioning and Aliases
            Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Enabled: Specifies whether AWS Lambda should actively poll the stream or not. If disabled, AWS Lambda will not poll the stream.
    :type Enabled: boolean
    :param BatchSize: The maximum number of stream records that can be sent to your Lambda function for a single invocation.
    :type BatchSize: integer
    """
    pass

def update_function_code(FunctionName=None, ZipFile=None, S3Bucket=None, S3Key=None, S3ObjectVersion=None, Publish=None):
    """
    :param FunctionName: [REQUIRED]
            The existing Lambda function name whose code you want to replace.
            You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param ZipFile: The contents of your zip file containing your deployment package. If you are using the web API directly, the contents of the zip file must be base64-encoded. If you are using the AWS SDKs or the AWS CLI, the SDKs or CLI will do the encoding for you. For more information about creating a .zip file, go to Execution Permissions in the AWS Lambda Developer Guide .
            This value will be base64 encoded automatically. Do not base64 encode this value prior to performing the operation.
            
    :type ZipFile: bytes
    :param S3Bucket: Amazon S3 bucket name where the .zip file containing your deployment package is stored. This bucket must reside in the same AWS region where you are creating the Lambda function.
    :type S3Bucket: string
    :param S3Key: The Amazon S3 object (the deployment package) key name you want to upload.
    :type S3Key: string
    :param S3ObjectVersion: The Amazon S3 object (the deployment package) version you want to upload.
    :type S3ObjectVersion: string
    :param Publish: This boolean parameter can be used to request AWS Lambda to update the Lambda function and publish a version as an atomic operation.
    :type Publish: boolean
    """
    pass

def update_function_configuration(FunctionName=None, Role=None, Handler=None, Description=None, Timeout=None, MemorySize=None, VpcConfig=None, Runtime=None):
    """
    :param FunctionName: [REQUIRED]
            The name of the Lambda function.
            You can specify a function name (for example, Thumbnail ) or you can specify Amazon Resource Name (ARN) of the function (for example, arn:aws:lambda:us-west-2:account-id:function:ThumbNail ). AWS Lambda also allows you to specify a partial ARN (for example, account-id:Thumbnail ). Note that the length constraint applies only to the ARN. If you specify only the function name, it is limited to 64 character in length.
            
    :type FunctionName: string
    :param Role: The Amazon Resource Name (ARN) of the IAM role that Lambda will assume when it executes your function.
    :type Role: string
    :param Handler: The function that Lambda calls to begin executing your function. For Node.js, it is the module-name.export value in your function.
    :type Handler: string
    :param Description: A short user-defined function description. AWS Lambda does not use this value. Assign a meaningful description as you see fit.
    :type Description: string
    :param Timeout: The function execution time at which AWS Lambda should terminate the function. Because the execution time has cost implications, we recommend you set this value based on your expected execution time. The default is 3 seconds.
    :type Timeout: integer
    :param MemorySize: The amount of memory, in MB, your Lambda function is given. AWS Lambda uses this memory size to infer the amount of CPU allocated to your function. Your function use-case determines your CPU and memory requirements. For example, a database operation might need less memory compared to an image processing function. The default value is 128 MB. The value must be a multiple of 64 MB.
    :type MemorySize: integer
    :param VpcConfig: If your Lambda function accesses resources in a VPC, you provide this parameter identifying the list of security group IDs and subnet IDs. These must belong to the same VPC. You must provide at least one security group and one subnet ID.
            SubnetIds (list) --A list of one or more subnet IDs in your VPC.
            (string) --
            SecurityGroupIds (list) --A list of one or more security groups IDs in your VPC.
            (string) --
            
    :type VpcConfig: dict
    :param Runtime: The runtime environment for the Lambda function.
            To use the Node.js runtime v4.3, set the value to 'nodejs4.3'. To use earlier runtime (v0.10.42), set the value to 'nodejs'.
            
    :type Runtime: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def bulk_publish(IdentityPoolId=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
            Return typedict
            ReturnsResponse Syntax{
              'IdentityPoolId': 'string'
            }
            Response Structure
            (dict) -- The output for the BulkPublish operation.
            IdentityPoolId (string) -- A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
            
            
    :type IdentityPoolId: string
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def delete_dataset(IdentityPoolId=None, IdentityId=None, DatasetName=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityId: string
    :param DatasetName: [REQUIRED] A string of up to 128 characters. Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-' (dash), and '.' (dot).
    :type DatasetName: string
    """
    pass

def describe_dataset(IdentityPoolId=None, IdentityId=None, DatasetName=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityId: string
    :param DatasetName: [REQUIRED] A string of up to 128 characters. Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-' (dash), and '.' (dot).
    :type DatasetName: string
    """
    pass

def describe_identity_pool_usage(IdentityPoolId=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
            Return typedict
            ReturnsResponse Syntax{
              'IdentityPoolUsage': {
                'IdentityPoolId': 'string',
                'SyncSessionsCount': 123,
                'DataStorage': 123,
                'LastModifiedDate': datetime(2015, 1, 1)
              }
            }
            Response Structure
            (dict) -- Response to a successful DescribeIdentityPoolUsage request.
            IdentityPoolUsage (dict) -- Information about the usage of the identity pool.
            IdentityPoolId (string) -- A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
            SyncSessionsCount (integer) -- Number of sync sessions for the identity pool.
            DataStorage (integer) -- Data storage information for the identity pool.
            LastModifiedDate (datetime) -- Date on which the identity pool was last modified.
            
            
    :type IdentityPoolId: string
    """
    pass

def describe_identity_usage(IdentityPoolId=None, IdentityId=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityId: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_bulk_publish_details(IdentityPoolId=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
            Return typedict
            ReturnsResponse Syntax{
              'IdentityPoolId': 'string',
              'BulkPublishStartTime': datetime(2015, 1, 1),
              'BulkPublishCompleteTime': datetime(2015, 1, 1),
              'BulkPublishStatus': 'NOT_STARTED'|'IN_PROGRESS'|'FAILED'|'SUCCEEDED',
              'FailureMessage': 'string'
            }
            Response Structure
            (dict) -- The output for the GetBulkPublishDetails operation.
            IdentityPoolId (string) -- A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
            BulkPublishStartTime (datetime) -- The date/time at which the last bulk publish was initiated.
            BulkPublishCompleteTime (datetime) -- If BulkPublishStatus is SUCCEEDED, the time the last bulk publish operation completed.
            BulkPublishStatus (string) -- Status of the last bulk publish operation, valid values are:NOT_STARTED - No bulk publish has been requested for this identity pool
            IN_PROGRESS - Data is being published to the configured stream
            SUCCEEDED - All data for the identity pool has been published to the configured stream
            FAILED - Some portion of the data has failed to publish, check FailureMessage for the cause.
            FailureMessage (string) -- If BulkPublishStatus is FAILED this field will contain the error message that caused the bulk publish to fail.
            
            
    :type IdentityPoolId: string
    """
    pass

def get_cognito_events(IdentityPoolId=None):
    """
    :param IdentityPoolId: [REQUIRED]
            The Cognito Identity Pool ID for the request
            Return typedict
            ReturnsResponse Syntax{
              'Events': {
                'string': 'string'
              }
            }
            Response Structure
            (dict) --The response from the GetCognitoEvents request
            Events (dict) --The Cognito Events returned from the GetCognitoEvents request
            (string) --
            (string) --
            
            
            
    :type IdentityPoolId: string
    """
    pass

def get_identity_pool_configuration(IdentityPoolId=None):
    """
    :param IdentityPoolId: [REQUIRED]
            A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. This is the ID of the pool for which to return a configuration.
            Return typedict
            ReturnsResponse Syntax{
              'IdentityPoolId': 'string',
              'PushSync': {
                'ApplicationArns': [
                  'string',
                ],
                'RoleArn': 'string'
              },
              'CognitoStreams': {
                'StreamName': 'string',
                'RoleArn': 'string',
                'StreamingStatus': 'ENABLED'|'DISABLED'
              }
            }
            Response Structure
            (dict) --The output for the GetIdentityPoolConfiguration operation.
            IdentityPoolId (string) --A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito.
            PushSync (dict) --Options to apply to this identity pool for push synchronization.
            ApplicationArns (list) --List of SNS platform application ARNs that could be used by clients.
            (string) --
            RoleArn (string) --A role configured to allow Cognito to call SNS on behalf of the developer.
            CognitoStreams (dict) -- Options to apply to this identity pool for Amazon Cognito streams.
            StreamName (string) -- The name of the Cognito stream to receive updates. This stream must be in the developers account and in the same region as the identity pool.
            RoleArn (string) -- The ARN of the role Amazon Cognito can assume in order to publish to the stream. This role must grant access to Amazon Cognito (cognito-sync) to invoke PutRecord on your Cognito stream.
            StreamingStatus (string) -- Status of the Cognito streams. Valid values are:ENABLED - Streaming of updates to identity pool is enabled.
            DISABLED - Streaming of updates to identity pool is disabled. Bulk publish will also fail if StreamingStatus is DISABLED.
            
            
            
    :type IdentityPoolId: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_datasets(IdentityPoolId=None, IdentityId=None, NextToken=None, MaxResults=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityId: string
    :param NextToken: A pagination token for obtaining the next page of results.
    :type NextToken: string
    :param MaxResults: The maximum number of results to be returned.
    :type MaxResults: integer
    """
    pass

def list_identity_pool_usage(NextToken=None, MaxResults=None):
    """
    :param NextToken: A pagination token for obtaining the next page of results.
    :type NextToken: string
    :param MaxResults: The maximum number of results to be returned.
    :type MaxResults: integer
    """
    pass

def list_records(IdentityPoolId=None, IdentityId=None, DatasetName=None, LastSyncCount=None, NextToken=None, MaxResults=None, SyncSessionToken=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityId: string
    :param DatasetName: [REQUIRED] A string of up to 128 characters. Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-' (dash), and '.' (dot).
    :type DatasetName: string
    :param LastSyncCount: The last server sync count for this record.
    :type LastSyncCount: integer
    :param NextToken: A pagination token for obtaining the next page of results.
    :type NextToken: string
    :param MaxResults: The maximum number of results to be returned.
    :type MaxResults: integer
    :param SyncSessionToken: A token containing a session ID, identity ID, and expiration.
    :type SyncSessionToken: string
    """
    pass

def register_device(IdentityPoolId=None, IdentityId=None, Platform=None, Token=None):
    """
    :param IdentityPoolId: [REQUIRED]
            A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. Here, the ID of the pool that the identity belongs to.
            
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED]
            The unique ID for this identity.
            
    :type IdentityId: string
    :param Platform: [REQUIRED]
            The SNS platform type (e.g. GCM, SDM, APNS, APNS_SANDBOX).
            
    :type Platform: string
    :param Token: [REQUIRED]
            The push token.
            
    :type Token: string
    """
    pass

def set_cognito_events(IdentityPoolId=None, Events=None):
    """
    :param IdentityPoolId: [REQUIRED]
            The Cognito Identity Pool to use when configuring Cognito Events
            
    :type IdentityPoolId: string
    :param Events: [REQUIRED]
            The events to configure
            (string) --
            (string) --
            
    :type Events: dict
    """
    pass

def set_identity_pool_configuration(IdentityPoolId=None, PushSync=None, CognitoStreams=None):
    """
    :param IdentityPoolId: [REQUIRED]
            A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. This is the ID of the pool to modify.
            
    :type IdentityPoolId: string
    :param PushSync: Options to apply to this identity pool for push synchronization.
            ApplicationArns (list) --List of SNS platform application ARNs that could be used by clients.
            (string) --
            RoleArn (string) --A role configured to allow Cognito to call SNS on behalf of the developer.
            
    :type PushSync: dict
    :param CognitoStreams: Options to apply to this identity pool for Amazon Cognito streams.
            StreamName (string) -- The name of the Cognito stream to receive updates. This stream must be in the developers account and in the same region as the identity pool.
            RoleArn (string) -- The ARN of the role Amazon Cognito can assume in order to publish to the stream. This role must grant access to Amazon Cognito (cognito-sync) to invoke PutRecord on your Cognito stream.
            StreamingStatus (string) -- Status of the Cognito streams. Valid values are:ENABLED - Streaming of updates to identity pool is enabled.
            DISABLED - Streaming of updates to identity pool is disabled. Bulk publish will also fail if StreamingStatus is DISABLED.
            
    :type CognitoStreams: dict
    """
    pass

def subscribe_to_dataset(IdentityPoolId=None, IdentityId=None, DatasetName=None, DeviceId=None):
    """
    :param IdentityPoolId: [REQUIRED]
            A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. The ID of the pool to which the identity belongs.
            
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED]
            Unique ID for this identity.
            
    :type IdentityId: string
    :param DatasetName: [REQUIRED]
            The name of the dataset to subcribe to.
            
    :type DatasetName: string
    :param DeviceId: [REQUIRED]
            The unique ID generated for this device by Cognito.
            
    :type DeviceId: string
    """
    pass

def unsubscribe_from_dataset(IdentityPoolId=None, IdentityId=None, DatasetName=None, DeviceId=None):
    """
    :param IdentityPoolId: [REQUIRED]
            A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. The ID of the pool to which this identity belongs.
            
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED]
            Unique ID for this identity.
            
    :type IdentityId: string
    :param DatasetName: [REQUIRED]
            The name of the dataset from which to unsubcribe.
            
    :type DatasetName: string
    :param DeviceId: [REQUIRED]
            The unique ID generated for this device by Cognito.
            
    :type DeviceId: string
    """
    pass

def update_records(IdentityPoolId=None, IdentityId=None, DatasetName=None, DeviceId=None, RecordPatches=None, SyncSessionToken=None, ClientContext=None):
    """
    :param IdentityPoolId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityPoolId: string
    :param IdentityId: [REQUIRED] A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. GUID generation is unique within a region.
    :type IdentityId: string
    :param DatasetName: [REQUIRED] A string of up to 128 characters. Allowed characters are a-z, A-Z, 0-9, '_' (underscore), '-' (dash), and '.' (dot).
    :type DatasetName: string
    :param DeviceId: The unique ID generated for this device by Cognito.
    :type DeviceId: string
    :param RecordPatches: A list of patch operations.
            (dict) -- An update operation for a record.
            Op (string) -- [REQUIRED] An operation, either replace or remove.
            Key (string) -- [REQUIRED] The key associated with the record patch.
            Value (string) -- The value associated with the record patch.
            SyncCount (integer) -- [REQUIRED] Last known server sync count for this record. Set to 0 if unknown.
            DeviceLastModifiedDate (datetime) -- The last modified date of the client device.
            
    :type RecordPatches: list
    :param SyncSessionToken: [REQUIRED] The SyncSessionToken returned by a previous call to ListRecords for this dataset and identity.
    :type SyncSessionToken: string
    :param ClientContext: Intended to supply a device ID that will populate the lastModifiedBy field referenced in other methods. The ClientContext field is not yet implemented.
    :type ClientContext: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_tags(ARN=None, TagList=None):
    """
    :param ARN: [REQUIRED]
            Specify the ARN for which you want to add the tags.
            
    :type ARN: string
    :param TagList: [REQUIRED]
            List of Tag that need to be added for the Elasticsearch domain.
            (dict) --Specifies a key value pair for a resource tag.
            Key (string) -- [REQUIRED]Specifies the TagKey , the name of the tag. Tag keys must be unique for the Elasticsearch domain to which they are attached.
            Value (string) -- [REQUIRED]Specifies the TagValue , the value assigned to the corresponding tag key. Tag values can be null and do not have to be unique in a tag set. For example, you can have a key value pair in a tag set of project : Trinity and cost-center : Trinity
            
            
    :type TagList: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_elasticsearch_domain(DomainName=None, ElasticsearchVersion=None, ElasticsearchClusterConfig=None, EBSOptions=None, AccessPolicies=None, SnapshotOptions=None, AdvancedOptions=None):
    """
    :param DomainName: [REQUIRED]
            The name of the Elasticsearch domain that you are creating. Domain names are unique across the domains owned by an account within an AWS region. Domain names must start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param ElasticsearchVersion: String of format X.Y to specify version for the Elasticsearch domain eg. '1.5' or '2.3'. For more information, see Creating Elasticsearch Domains in the Amazon Elasticsearch Service Developer Guide .
    :type ElasticsearchVersion: string
    :param ElasticsearchClusterConfig: Configuration options for an Elasticsearch domain. Specifies the instance type and number of instances in the domain cluster.
            InstanceType (string) --The instance type for an Elasticsearch cluster.
            InstanceCount (integer) --The number of instances in the specified domain cluster.
            DedicatedMasterEnabled (boolean) --A boolean value to indicate whether a dedicated master node is enabled. See About Dedicated Master Nodes for more information.
            ZoneAwarenessEnabled (boolean) --A boolean value to indicate whether zone awareness is enabled. See About Zone Awareness for more information.
            DedicatedMasterType (string) --The instance type for a dedicated master node.
            DedicatedMasterCount (integer) --Total number of dedicated master nodes, active and on standby, for the cluster.
            
    :type ElasticsearchClusterConfig: dict
    :param EBSOptions: Options to enable, disable and specify the type and size of EBS storage volumes.
            EBSEnabled (boolean) --Specifies whether EBS-based storage is enabled.
            VolumeType (string) --Specifies the volume type for EBS-based storage.
            VolumeSize (integer) --Integer to specify the size of an EBS volume.
            Iops (integer) --Specifies the IOPD for a Provisioned IOPS EBS volume (SSD).
            
    :type EBSOptions: dict
    :param AccessPolicies: IAM access policy as a JSON-formatted string.
    :type AccessPolicies: string
    :param SnapshotOptions: Option to set time, in UTC format, of the daily automated snapshot. Default value is 0 hours.
            AutomatedSnapshotStartHour (integer) --Specifies the time, in UTC format, when the service takes a daily automated snapshot of the specified Elasticsearch domain. Default value is 0 hours.
            
    :type SnapshotOptions: dict
    :param AdvancedOptions: Option to allow references to indices in an HTTP request body. Must be false when configuring access to individual sub-resources. By default, the value is true . See Configuration Advanced Options for more information.
            (string) --
            (string) --
            
    :type AdvancedOptions: dict
    """
    pass

def delete_elasticsearch_domain(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The name of the Elasticsearch domain that you want to permanently delete.
            Return typedict
            ReturnsResponse Syntax{
              'DomainStatus': {
                'DomainId': 'string',
                'DomainName': 'string',
                'ARN': 'string',
                'Created': True|False,
                'Deleted': True|False,
                'Endpoint': 'string',
                'Processing': True|False,
                'ElasticsearchVersion': 'string',
                'ElasticsearchClusterConfig': {
                  'InstanceType': 'm3.medium.elasticsearch'|'m3.large.elasticsearch'|'m3.xlarge.elasticsearch'|'m3.2xlarge.elasticsearch'|'m4.large.elasticsearch'|'m4.xlarge.elasticsearch'|'m4.2xlarge.elasticsearch'|'m4.4xlarge.elasticsearch'|'m4.10xlarge.elasticsearch'|'t2.micro.elasticsearch'|'t2.small.elasticsearch'|'t2.medium.elasticsearch'|'r3.large.elasticsearch'|'r3.xlarge.elasticsearch'|'r3.2xlarge.elasticsearch'|'r3.4xlarge.elasticsearch'|'r3.8xlarge.elasticsearch'|'i2.xlarge.elasticsearch'|'i2.2xlarge.elasticsearch',
                  'InstanceCount': 123,
                  'DedicatedMasterEnabled': True|False,
                  'ZoneAwarenessEnabled': True|False,
                  'DedicatedMasterType': 'm3.medium.elasticsearch'|'m3.large.elasticsearch'|'m3.xlarge.elasticsearch'|'m3.2xlarge.elasticsearch'|'m4.large.elasticsearch'|'m4.xlarge.elasticsearch'|'m4.2xlarge.elasticsearch'|'m4.4xlarge.elasticsearch'|'m4.10xlarge.elasticsearch'|'t2.micro.elasticsearch'|'t2.small.elasticsearch'|'t2.medium.elasticsearch'|'r3.large.elasticsearch'|'r3.xlarge.elasticsearch'|'r3.2xlarge.elasticsearch'|'r3.4xlarge.elasticsearch'|'r3.8xlarge.elasticsearch'|'i2.xlarge.elasticsearch'|'i2.2xlarge.elasticsearch',
                  'DedicatedMasterCount': 123
                },
                'EBSOptions': {
                  'EBSEnabled': True|False,
                  'VolumeType': 'standard'|'gp2'|'io1',
                  'VolumeSize': 123,
                  'Iops': 123
                },
                'AccessPolicies': 'string',
                'SnapshotOptions': {
                  'AutomatedSnapshotStartHour': 123
                },
                'AdvancedOptions': {
                  'string': 'string'
                }
              }
            }
            Response Structure
            (dict) --The result of a DeleteElasticsearchDomain request. Contains the status of the pending deletion, or no status if the domain and all of its resources have been deleted.
            DomainStatus (dict) --The status of the Elasticsearch domain being deleted.
            DomainId (string) --The unique identifier for the specified Elasticsearch domain.
            DomainName (string) --The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            ARN (string) --The Amazon resource name (ARN) of an Elasticsearch domain. See Identifiers for IAM Entities in Using AWS Identity and Access Management for more information.
            Created (boolean) --The domain creation status. True if the creation of an Elasticsearch domain is complete. False if domain creation is still in progress.
            Deleted (boolean) --The domain deletion status. True if a delete request has been received for the domain but resource cleanup is still in progress. False if the domain has not been deleted. Once domain deletion is complete, the status of the domain is no longer returned.
            Endpoint (string) --The Elasticsearch domain endpoint that you use to submit index and search requests.
            Processing (boolean) --The status of the Elasticsearch domain configuration. True if Amazon Elasticsearch Service is processing configuration changes. False if the configuration is active.
            ElasticsearchVersion (string) --
            ElasticsearchClusterConfig (dict) --The type and number of instances in the domain cluster.
            InstanceType (string) --The instance type for an Elasticsearch cluster.
            InstanceCount (integer) --The number of instances in the specified domain cluster.
            DedicatedMasterEnabled (boolean) --A boolean value to indicate whether a dedicated master node is enabled. See About Dedicated Master Nodes for more information.
            ZoneAwarenessEnabled (boolean) --A boolean value to indicate whether zone awareness is enabled. See About Zone Awareness for more information.
            DedicatedMasterType (string) --The instance type for a dedicated master node.
            DedicatedMasterCount (integer) --Total number of dedicated master nodes, active and on standby, for the cluster.
            EBSOptions (dict) --The EBSOptions for the specified domain. See Configuring EBS-based Storage for more information.
            EBSEnabled (boolean) --Specifies whether EBS-based storage is enabled.
            VolumeType (string) --Specifies the volume type for EBS-based storage.
            VolumeSize (integer) --Integer to specify the size of an EBS volume.
            Iops (integer) --Specifies the IOPD for a Provisioned IOPS EBS volume (SSD).
            AccessPolicies (string) --IAM access policy as a JSON-formatted string.
            SnapshotOptions (dict) --Specifies the status of the SnapshotOptions
            AutomatedSnapshotStartHour (integer) --Specifies the time, in UTC format, when the service takes a daily automated snapshot of the specified Elasticsearch domain. Default value is 0 hours.
            AdvancedOptions (dict) --Specifies the status of the AdvancedOptions
            (string) --
            (string) --
            
            
            
    :type DomainName: string
    """
    pass

def describe_elasticsearch_domain(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The name of the Elasticsearch domain for which you want information.
            Return typedict
            ReturnsResponse Syntax{
              'DomainStatus': {
                'DomainId': 'string',
                'DomainName': 'string',
                'ARN': 'string',
                'Created': True|False,
                'Deleted': True|False,
                'Endpoint': 'string',
                'Processing': True|False,
                'ElasticsearchVersion': 'string',
                'ElasticsearchClusterConfig': {
                  'InstanceType': 'm3.medium.elasticsearch'|'m3.large.elasticsearch'|'m3.xlarge.elasticsearch'|'m3.2xlarge.elasticsearch'|'m4.large.elasticsearch'|'m4.xlarge.elasticsearch'|'m4.2xlarge.elasticsearch'|'m4.4xlarge.elasticsearch'|'m4.10xlarge.elasticsearch'|'t2.micro.elasticsearch'|'t2.small.elasticsearch'|'t2.medium.elasticsearch'|'r3.large.elasticsearch'|'r3.xlarge.elasticsearch'|'r3.2xlarge.elasticsearch'|'r3.4xlarge.elasticsearch'|'r3.8xlarge.elasticsearch'|'i2.xlarge.elasticsearch'|'i2.2xlarge.elasticsearch',
                  'InstanceCount': 123,
                  'DedicatedMasterEnabled': True|False,
                  'ZoneAwarenessEnabled': True|False,
                  'DedicatedMasterType': 'm3.medium.elasticsearch'|'m3.large.elasticsearch'|'m3.xlarge.elasticsearch'|'m3.2xlarge.elasticsearch'|'m4.large.elasticsearch'|'m4.xlarge.elasticsearch'|'m4.2xlarge.elasticsearch'|'m4.4xlarge.elasticsearch'|'m4.10xlarge.elasticsearch'|'t2.micro.elasticsearch'|'t2.small.elasticsearch'|'t2.medium.elasticsearch'|'r3.large.elasticsearch'|'r3.xlarge.elasticsearch'|'r3.2xlarge.elasticsearch'|'r3.4xlarge.elasticsearch'|'r3.8xlarge.elasticsearch'|'i2.xlarge.elasticsearch'|'i2.2xlarge.elasticsearch',
                  'DedicatedMasterCount': 123
                },
                'EBSOptions': {
                  'EBSEnabled': True|False,
                  'VolumeType': 'standard'|'gp2'|'io1',
                  'VolumeSize': 123,
                  'Iops': 123
                },
                'AccessPolicies': 'string',
                'SnapshotOptions': {
                  'AutomatedSnapshotStartHour': 123
                },
                'AdvancedOptions': {
                  'string': 'string'
                }
              }
            }
            Response Structure
            (dict) --The result of a DescribeElasticsearchDomain request. Contains the status of the domain specified in the request.
            DomainStatus (dict) --The current status of the Elasticsearch domain.
            DomainId (string) --The unique identifier for the specified Elasticsearch domain.
            DomainName (string) --The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            ARN (string) --The Amazon resource name (ARN) of an Elasticsearch domain. See Identifiers for IAM Entities in Using AWS Identity and Access Management for more information.
            Created (boolean) --The domain creation status. True if the creation of an Elasticsearch domain is complete. False if domain creation is still in progress.
            Deleted (boolean) --The domain deletion status. True if a delete request has been received for the domain but resource cleanup is still in progress. False if the domain has not been deleted. Once domain deletion is complete, the status of the domain is no longer returned.
            Endpoint (string) --The Elasticsearch domain endpoint that you use to submit index and search requests.
            Processing (boolean) --The status of the Elasticsearch domain configuration. True if Amazon Elasticsearch Service is processing configuration changes. False if the configuration is active.
            ElasticsearchVersion (string) --
            ElasticsearchClusterConfig (dict) --The type and number of instances in the domain cluster.
            InstanceType (string) --The instance type for an Elasticsearch cluster.
            InstanceCount (integer) --The number of instances in the specified domain cluster.
            DedicatedMasterEnabled (boolean) --A boolean value to indicate whether a dedicated master node is enabled. See About Dedicated Master Nodes for more information.
            ZoneAwarenessEnabled (boolean) --A boolean value to indicate whether zone awareness is enabled. See About Zone Awareness for more information.
            DedicatedMasterType (string) --The instance type for a dedicated master node.
            DedicatedMasterCount (integer) --Total number of dedicated master nodes, active and on standby, for the cluster.
            EBSOptions (dict) --The EBSOptions for the specified domain. See Configuring EBS-based Storage for more information.
            EBSEnabled (boolean) --Specifies whether EBS-based storage is enabled.
            VolumeType (string) --Specifies the volume type for EBS-based storage.
            VolumeSize (integer) --Integer to specify the size of an EBS volume.
            Iops (integer) --Specifies the IOPD for a Provisioned IOPS EBS volume (SSD).
            AccessPolicies (string) --IAM access policy as a JSON-formatted string.
            SnapshotOptions (dict) --Specifies the status of the SnapshotOptions
            AutomatedSnapshotStartHour (integer) --Specifies the time, in UTC format, when the service takes a daily automated snapshot of the specified Elasticsearch domain. Default value is 0 hours.
            AdvancedOptions (dict) --Specifies the status of the AdvancedOptions
            (string) --
            (string) --
            
            
            
    :type DomainName: string
    """
    pass

def describe_elasticsearch_domain_config(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The Elasticsearch domain that you want to get information about.
            Return typedict
            ReturnsResponse Syntax{
              'DomainConfig': {
                'ElasticsearchVersion': {
                  'Options': 'string',
                  'Status': {
                    'CreationDate': datetime(2015, 1, 1),
                    'UpdateDate': datetime(2015, 1, 1),
                    'UpdateVersion': 123,
                    'State': 'RequiresIndexDocuments'|'Processing'|'Active',
                    'PendingDeletion': True|False
                  }
                },
                'ElasticsearchClusterConfig': {
                  'Options': {
                    'InstanceType': 'm3.medium.elasticsearch'|'m3.large.elasticsearch'|'m3.xlarge.elasticsearch'|'m3.2xlarge.elasticsearch'|'m4.large.elasticsearch'|'m4.xlarge.elasticsearch'|'m4.2xlarge.elasticsearch'|'m4.4xlarge.elasticsearch'|'m4.10xlarge.elasticsearch'|'t2.micro.elasticsearch'|'t2.small.elasticsearch'|'t2.medium.elasticsearch'|'r3.large.elasticsearch'|'r3.xlarge.elasticsearch'|'r3.2xlarge.elasticsearch'|'r3.4xlarge.elasticsearch'|'r3.8xlarge.elasticsearch'|'i2.xlarge.elasticsearch'|'i2.2xlarge.elasticsearch',
                    'InstanceCount': 123,
                    'DedicatedMasterEnabled': True|False,
                    'ZoneAwarenessEnabled': True|False,
                    'DedicatedMasterType': 'm3.medium.elasticsearch'|'m3.large.elasticsearch'|'m3.xlarge.elasticsearch'|'m3.2xlarge.elasticsearch'|'m4.large.elasticsearch'|'m4.xlarge.elasticsearch'|'m4.2xlarge.elasticsearch'|'m4.4xlarge.elasticsearch'|'m4.10xlarge.elasticsearch'|'t2.micro.elasticsearch'|'t2.small.elasticsearch'|'t2.medium.elasticsearch'|'r3.large.elasticsearch'|'r3.xlarge.elasticsearch'|'r3.2xlarge.elasticsearch'|'r3.4xlarge.elasticsearch'|'r3.8xlarge.elasticsearch'|'i2.xlarge.elasticsearch'|'i2.2xlarge.elasticsearch',
                    'DedicatedMasterCount': 123
                  },
                  'Status': {
                    'CreationDate': datetime(2015, 1, 1),
                    'UpdateDate': datetime(2015, 1, 1),
                    'UpdateVersion': 123,
                    'State': 'RequiresIndexDocuments'|'Processing'|'Active',
                    'PendingDeletion': True|False
                  }
                },
                'EBSOptions': {
                  'Options': {
                    'EBSEnabled': True|False,
                    'VolumeType': 'standard'|'gp2'|'io1',
                    'VolumeSize': 123,
                    'Iops': 123
                  },
                  'Status': {
                    'CreationDate': datetime(2015, 1, 1),
                    'UpdateDate': datetime(2015, 1, 1),
                    'UpdateVersion': 123,
                    'State': 'RequiresIndexDocuments'|'Processing'|'Active',
                    'PendingDeletion': True|False
                  }
                },
                'AccessPolicies': {
                  'Options': 'string',
                  'Status': {
                    'CreationDate': datetime(2015, 1, 1),
                    'UpdateDate': datetime(2015, 1, 1),
                    'UpdateVersion': 123,
                    'State': 'RequiresIndexDocuments'|'Processing'|'Active',
                    'PendingDeletion': True|False
                  }
                },
                'SnapshotOptions': {
                  'Options': {
                    'AutomatedSnapshotStartHour': 123
                  },
                  'Status': {
                    'CreationDate': datetime(2015, 1, 1),
                    'UpdateDate': datetime(2015, 1, 1),
                    'UpdateVersion': 123,
                    'State': 'RequiresIndexDocuments'|'Processing'|'Active',
                    'PendingDeletion': True|False
                  }
                },
                'AdvancedOptions': {
                  'Options': {
                    'string': 'string'
                  },
                  'Status': {
                    'CreationDate': datetime(2015, 1, 1),
                    'UpdateDate': datetime(2015, 1, 1),
                    'UpdateVersion': 123,
                    'State': 'RequiresIndexDocuments'|'Processing'|'Active',
                    'PendingDeletion': True|False
                  }
                }
              }
            }
            Response Structure
            (dict) --The result of a DescribeElasticsearchDomainConfig request. Contains the configuration information of the requested domain.
            DomainConfig (dict) --The configuration information of the domain requested in the DescribeElasticsearchDomainConfig request.
            ElasticsearchVersion (dict) --String of format X.Y to specify version for the Elasticsearch domain.
            Options (string) --Specifies the Elasticsearch version for the specified Elasticsearch domain.
            Status (dict) --Specifies the status of the Elasticsearch version options for the specified Elasticsearch domain.
            CreationDate (datetime) --Timestamp which tells the creation date for the entity.
            UpdateDate (datetime) --Timestamp which tells the last updated time for the entity.
            UpdateVersion (integer) --Specifies the latest version for the entity.
            State (string) --Provides the OptionState for the Elasticsearch domain.
            PendingDeletion (boolean) --Indicates whether the Elasticsearch domain is being deleted.
            
            ElasticsearchClusterConfig (dict) --Specifies the ElasticsearchClusterConfig for the Elasticsearch domain.
            Options (dict) --Specifies the cluster configuration for the specified Elasticsearch domain.
            InstanceType (string) --The instance type for an Elasticsearch cluster.
            InstanceCount (integer) --The number of instances in the specified domain cluster.
            DedicatedMasterEnabled (boolean) --A boolean value to indicate whether a dedicated master node is enabled. See About Dedicated Master Nodes for more information.
            ZoneAwarenessEnabled (boolean) --A boolean value to indicate whether zone awareness is enabled. See About Zone Awareness for more information.
            DedicatedMasterType (string) --The instance type for a dedicated master node.
            DedicatedMasterCount (integer) --Total number of dedicated master nodes, active and on standby, for the cluster.
            Status (dict) --Specifies the status of the configuration for the specified Elasticsearch domain.
            CreationDate (datetime) --Timestamp which tells the creation date for the entity.
            UpdateDate (datetime) --Timestamp which tells the last updated time for the entity.
            UpdateVersion (integer) --Specifies the latest version for the entity.
            State (string) --Provides the OptionState for the Elasticsearch domain.
            PendingDeletion (boolean) --Indicates whether the Elasticsearch domain is being deleted.
            
            EBSOptions (dict) --Specifies the EBSOptions for the Elasticsearch domain.
            Options (dict) --Specifies the EBS options for the specified Elasticsearch domain.
            EBSEnabled (boolean) --Specifies whether EBS-based storage is enabled.
            VolumeType (string) --Specifies the volume type for EBS-based storage.
            VolumeSize (integer) --Integer to specify the size of an EBS volume.
            Iops (integer) --Specifies the IOPD for a Provisioned IOPS EBS volume (SSD).
            Status (dict) --Specifies the status of the EBS options for the specified Elasticsearch domain.
            CreationDate (datetime) --Timestamp which tells the creation date for the entity.
            UpdateDate (datetime) --Timestamp which tells the last updated time for the entity.
            UpdateVersion (integer) --Specifies the latest version for the entity.
            State (string) --Provides the OptionState for the Elasticsearch domain.
            PendingDeletion (boolean) --Indicates whether the Elasticsearch domain is being deleted.
            
            AccessPolicies (dict) --IAM access policy as a JSON-formatted string.
            Options (string) --The access policy configured for the Elasticsearch domain. Access policies may be resource-based, IP-based, or IAM-based. See Configuring Access Policies for more information.
            Status (dict) --The status of the access policy for the Elasticsearch domain. See OptionStatus for the status information that's included.
            CreationDate (datetime) --Timestamp which tells the creation date for the entity.
            UpdateDate (datetime) --Timestamp which tells the last updated time for the entity.
            UpdateVersion (integer) --Specifies the latest version for the entity.
            State (string) --Provides the OptionState for the Elasticsearch domain.
            PendingDeletion (boolean) --Indicates whether the Elasticsearch domain is being deleted.
            
            SnapshotOptions (dict) --Specifies the SnapshotOptions for the Elasticsearch domain.
            Options (dict) --Specifies the daily snapshot options specified for the Elasticsearch domain.
            AutomatedSnapshotStartHour (integer) --Specifies the time, in UTC format, when the service takes a daily automated snapshot of the specified Elasticsearch domain. Default value is 0 hours.
            Status (dict) --Specifies the status of a daily automated snapshot.
            CreationDate (datetime) --Timestamp which tells the creation date for the entity.
            UpdateDate (datetime) --Timestamp which tells the last updated time for the entity.
            UpdateVersion (integer) --Specifies the latest version for the entity.
            State (string) --Provides the OptionState for the Elasticsearch domain.
            PendingDeletion (boolean) --Indicates whether the Elasticsearch domain is being deleted.
            
            AdvancedOptions (dict) --Specifies the AdvancedOptions for the domain. See Configuring Advanced Options for more information.
            Options (dict) --Specifies the status of advanced options for the specified Elasticsearch domain.
            (string) --
            (string) --
            
            Status (dict) --Specifies the status of OptionStatus for advanced options for the specified Elasticsearch domain.
            CreationDate (datetime) --Timestamp which tells the creation date for the entity.
            UpdateDate (datetime) --Timestamp which tells the last updated time for the entity.
            UpdateVersion (integer) --Specifies the latest version for the entity.
            State (string) --Provides the OptionState for the Elasticsearch domain.
            PendingDeletion (boolean) --Indicates whether the Elasticsearch domain is being deleted.
            
            
            
            
    :type DomainName: string
    """
    pass

def describe_elasticsearch_domains(DomainNames=None):
    """
    :param DomainNames: [REQUIRED]
            The Elasticsearch domains for which you want information.
            (string) --The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            Return typedict
            ReturnsResponse Syntax{
              'DomainStatusList': [
                {
                  'DomainId': 'string',
                  'DomainName': 'string',
                  'ARN': 'string',
                  'Created': True|False,
                  'Deleted': True|False,
                  'Endpoint': 'string',
                  'Processing': True|False,
                  'ElasticsearchVersion': 'string',
                  'ElasticsearchClusterConfig': {
                    'InstanceType': 'm3.medium.elasticsearch'|'m3.large.elasticsearch'|'m3.xlarge.elasticsearch'|'m3.2xlarge.elasticsearch'|'m4.large.elasticsearch'|'m4.xlarge.elasticsearch'|'m4.2xlarge.elasticsearch'|'m4.4xlarge.elasticsearch'|'m4.10xlarge.elasticsearch'|'t2.micro.elasticsearch'|'t2.small.elasticsearch'|'t2.medium.elasticsearch'|'r3.large.elasticsearch'|'r3.xlarge.elasticsearch'|'r3.2xlarge.elasticsearch'|'r3.4xlarge.elasticsearch'|'r3.8xlarge.elasticsearch'|'i2.xlarge.elasticsearch'|'i2.2xlarge.elasticsearch',
                    'InstanceCount': 123,
                    'DedicatedMasterEnabled': True|False,
                    'ZoneAwarenessEnabled': True|False,
                    'DedicatedMasterType': 'm3.medium.elasticsearch'|'m3.large.elasticsearch'|'m3.xlarge.elasticsearch'|'m3.2xlarge.elasticsearch'|'m4.large.elasticsearch'|'m4.xlarge.elasticsearch'|'m4.2xlarge.elasticsearch'|'m4.4xlarge.elasticsearch'|'m4.10xlarge.elasticsearch'|'t2.micro.elasticsearch'|'t2.small.elasticsearch'|'t2.medium.elasticsearch'|'r3.large.elasticsearch'|'r3.xlarge.elasticsearch'|'r3.2xlarge.elasticsearch'|'r3.4xlarge.elasticsearch'|'r3.8xlarge.elasticsearch'|'i2.xlarge.elasticsearch'|'i2.2xlarge.elasticsearch',
                    'DedicatedMasterCount': 123
                  },
                  'EBSOptions': {
                    'EBSEnabled': True|False,
                    'VolumeType': 'standard'|'gp2'|'io1',
                    'VolumeSize': 123,
                    'Iops': 123
                  },
                  'AccessPolicies': 'string',
                  'SnapshotOptions': {
                    'AutomatedSnapshotStartHour': 123
                  },
                  'AdvancedOptions': {
                    'string': 'string'
                  }
                },
              ]
            }
            Response Structure
            (dict) --The result of a DescribeElasticsearchDomains request. Contains the status of the specified domains or all domains owned by the account.
            DomainStatusList (list) --The status of the domains requested in the DescribeElasticsearchDomains request.
            (dict) --The current status of an Elasticsearch domain.
            DomainId (string) --The unique identifier for the specified Elasticsearch domain.
            DomainName (string) --The name of an Elasticsearch domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            ARN (string) --The Amazon resource name (ARN) of an Elasticsearch domain. See Identifiers for IAM Entities in Using AWS Identity and Access Management for more information.
            Created (boolean) --The domain creation status. True if the creation of an Elasticsearch domain is complete. False if domain creation is still in progress.
            Deleted (boolean) --The domain deletion status. True if a delete request has been received for the domain but resource cleanup is still in progress. False if the domain has not been deleted. Once domain deletion is complete, the status of the domain is no longer returned.
            Endpoint (string) --The Elasticsearch domain endpoint that you use to submit index and search requests.
            Processing (boolean) --The status of the Elasticsearch domain configuration. True if Amazon Elasticsearch Service is processing configuration changes. False if the configuration is active.
            ElasticsearchVersion (string) --
            ElasticsearchClusterConfig (dict) --The type and number of instances in the domain cluster.
            InstanceType (string) --The instance type for an Elasticsearch cluster.
            InstanceCount (integer) --The number of instances in the specified domain cluster.
            DedicatedMasterEnabled (boolean) --A boolean value to indicate whether a dedicated master node is enabled. See About Dedicated Master Nodes for more information.
            ZoneAwarenessEnabled (boolean) --A boolean value to indicate whether zone awareness is enabled. See About Zone Awareness for more information.
            DedicatedMasterType (string) --The instance type for a dedicated master node.
            DedicatedMasterCount (integer) --Total number of dedicated master nodes, active and on standby, for the cluster.
            EBSOptions (dict) --The EBSOptions for the specified domain. See Configuring EBS-based Storage for more information.
            EBSEnabled (boolean) --Specifies whether EBS-based storage is enabled.
            VolumeType (string) --Specifies the volume type for EBS-based storage.
            VolumeSize (integer) --Integer to specify the size of an EBS volume.
            Iops (integer) --Specifies the IOPD for a Provisioned IOPS EBS volume (SSD).
            AccessPolicies (string) --IAM access policy as a JSON-formatted string.
            SnapshotOptions (dict) --Specifies the status of the SnapshotOptions
            AutomatedSnapshotStartHour (integer) --Specifies the time, in UTC format, when the service takes a daily automated snapshot of the specified Elasticsearch domain. Default value is 0 hours.
            AdvancedOptions (dict) --Specifies the status of the AdvancedOptions
            (string) --
            (string) --
            
            
            
            
    :type DomainNames: list
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_domain_names():
    """
    """
    pass

def list_tags(ARN=None):
    """
    :param ARN: [REQUIRED]
            Specify the ARN for the Elasticsearch domain to which the tags are attached that you want to view.
            Return typedict
            ReturnsResponse Syntax{
              'TagList': [
                {
                  'Key': 'string',
                  'Value': 'string'
                },
              ]
            }
            Response Structure
            (dict) --The result of a ListTags operation. Contains tags for all requested Elasticsearch domains.
            TagList (list) --List of Tag for the requested Elasticsearch domain.
            (dict) --Specifies a key value pair for a resource tag.
            Key (string) --Specifies the TagKey , the name of the tag. Tag keys must be unique for the Elasticsearch domain to which they are attached.
            Value (string) --Specifies the TagValue , the value assigned to the corresponding tag key. Tag values can be null and do not have to be unique in a tag set. For example, you can have a key value pair in a tag set of project : Trinity and cost-center : Trinity
            
            
            
    :type ARN: string
    """
    pass

def remove_tags(ARN=None, TagKeys=None):
    """
    :param ARN: [REQUIRED]
            Specifies the ARN for the Elasticsearch domain from which you want to delete the specified tags.
            
    :type ARN: string
    :param TagKeys: [REQUIRED]
            Specifies the TagKey list which you want to remove from the Elasticsearch domain.
            (string) --
            
    :type TagKeys: list
    """
    pass

def update_elasticsearch_domain_config(DomainName=None, ElasticsearchClusterConfig=None, EBSOptions=None, SnapshotOptions=None, AdvancedOptions=None, AccessPolicies=None):
    """
    :param DomainName: [REQUIRED]
            The name of the Elasticsearch domain that you are updating.
            
    :type DomainName: string
    :param ElasticsearchClusterConfig: The type and number of instances to instantiate for the domain cluster.
            InstanceType (string) --The instance type for an Elasticsearch cluster.
            InstanceCount (integer) --The number of instances in the specified domain cluster.
            DedicatedMasterEnabled (boolean) --A boolean value to indicate whether a dedicated master node is enabled. See About Dedicated Master Nodes for more information.
            ZoneAwarenessEnabled (boolean) --A boolean value to indicate whether zone awareness is enabled. See About Zone Awareness for more information.
            DedicatedMasterType (string) --The instance type for a dedicated master node.
            DedicatedMasterCount (integer) --Total number of dedicated master nodes, active and on standby, for the cluster.
            
    :type ElasticsearchClusterConfig: dict
    :param EBSOptions: Specify the type and size of the EBS volume that you want to use.
            EBSEnabled (boolean) --Specifies whether EBS-based storage is enabled.
            VolumeType (string) --Specifies the volume type for EBS-based storage.
            VolumeSize (integer) --Integer to specify the size of an EBS volume.
            Iops (integer) --Specifies the IOPD for a Provisioned IOPS EBS volume (SSD).
            
    :type EBSOptions: dict
    :param SnapshotOptions: Option to set the time, in UTC format, for the daily automated snapshot. Default value is 0 hours.
            AutomatedSnapshotStartHour (integer) --Specifies the time, in UTC format, when the service takes a daily automated snapshot of the specified Elasticsearch domain. Default value is 0 hours.
            
    :type SnapshotOptions: dict
    :param AdvancedOptions: Modifies the advanced option to allow references to indices in an HTTP request body. Must be false when configuring access to individual sub-resources. By default, the value is true . See Configuration Advanced Options for more information.
            (string) --
            (string) --
            
    :type AdvancedOptions: dict
    :param AccessPolicies: IAM access policy as a JSON-formatted string.
    :type AccessPolicies: string
    """
    pass

